@@ -46,7 +46,7 @@ extern "C" {
 
 // Error identifier
 
-#define	 CDI_NOERR        	    0   // No Error
+#define  CDI_NOERR                  0   // No Error
 #define  CDI_EEOF                  -1   // The end of file was encountered
 #define  CDI_ETMOF                 -9   // Too many open files
 #define  CDI_ESYSTEM              -10   // Operating system error
@@ -180,6 +180,7 @@ extern "C" {
 #define  GRID_TRAJECTORY            8  // Trajectory
 #define  GRID_UNSTRUCTURED          9  // General unstructured grid
 #define  GRID_CURVILINEAR          10  // Curvilinear grid
+#define  GRID_HEALPIX              11  // HealPIX grid
 #define  GRID_PROJECTION           12  // Projected coordinates
 #define  GRID_CHARXY               13  // One horizontal character dimension
 
@@ -295,6 +296,12 @@ typedef struct  {
 #define  CALENDAR_366DAYS         5
 #define  CALENDAR_NONE            6
 
+#define  CDI_HAS_CGRIBEX          1
+#define  CDI_NC_HAS_FILTER        2
+#define  CDI_NC_HAS_DAP           3
+#define  CDI_NC_HAS_S3            4
+#define  CDI_NC_HAS_HDF5          5
+
 // number of unsigned char needed to store UUID
 #define  CDI_UUID_SIZE           16
 
@@ -317,7 +324,9 @@ void    cdiDebug(int debug);
 const char *cdiLibraryVersion(void);
 void    cdiPrintVersion(void);
 
-int     cdiHaveFiletype(int filetype);
+int     cdiHaveFiletype(int fileType);
+int     cdiGetConfig(int confType);
+
 
 void    cdiDefMissval(double missval);
 double  cdiInqMissval(void);
@@ -794,6 +803,9 @@ void    gridDefYsize(int gridID, SizeType ysize);
 //      gridInqYsize: Get the size of a Y-axis
 SizeType gridInqYsize(int gridID);
 
+void    gridDefIndices(int gridID, const int64_t *indices);
+SizeType gridInqIndices(int gridID, int64_t *indices);
+
 //      gridDefNP: Define the number of parallels between a pole and the equator
 void    gridDefNP(int gridID, int np);
 
@@ -1447,12 +1459,9 @@ extern int (*proj_lcc_to_lonlat_func)(struct CDI_GridProjParams gpp, double, dou
 extern int (*proj_lonlat_to_stere_func)(struct CDI_GridProjParams gpp, size_t, double*, double*);
 extern int (*proj_stere_to_lonlat_func)(struct CDI_GridProjParams gpp, double, double, size_t, double*, double*);
 
-// Used on CDO remap_scrip_io.cc
+// Used in CDO remap_scrip_io.cc
 void cdf_def_var_filter(int ncid, int ncvarID, const char *filterSpec);
 
-int cdi_has_dap(void);
-int cdi_has_cgribex(void);
-
 #ifdef __cplusplus
 }
 #endif
