@@ -280,10 +280,8 @@ cdiHaveFiletype(int filetype)
 #ifdef HAVE_NETCDF2
     case CDI_FILETYPE_NC2: status = 1; break;
 #endif
-#ifdef HAVE_NETCDF4
     case CDI_FILETYPE_NC4: status = 1; break;
     case CDI_FILETYPE_NC4C: status = 1; break;
-#endif
 #ifdef HAVE_NCZARR
     case CDI_FILETYPE_NCZARR: status = 1; break;
 #endif
@@ -592,33 +590,6 @@ stream_def_accesstype(stream_t *s, int type)
     Error("Changing access type from %s not allowed!", s->accesstype == TYPE_REC ? "REC to VAR" : "VAR to REC");
 }
 
-int
-cdi_has_ncfilter(void)
-{
-#ifdef HAVE_NC4FILTER
-  return 1;
-#endif
-  return 0;
-}
-
-int
-cdi_has_ncdap(void)
-{
-#ifdef HAVE_LIBNC_DAP
-  return 1;
-#endif
-  return 0;
-}
-
-int
-cdi_has_cgribex(void)
-{
-#ifdef HAVE_LIBCGRIBEX
-  return 1;
-#endif
-  return 0;
-}
-
 /*
  * Local Variables:
  * c-file-style: "Java"
