@@ -53,11 +53,11 @@ memcrc(const unsigned char *b, size_t n)
 
   /* Extend with the length of the string. */
   while (n != 0)
-    {
-      register uint32_t c = n & 0377;
-      n >>= 8;
-      s = (s << 8) ^ crctab[(s >> 24) ^ c];
-    }
+  {
+    register uint32_t c = n & 0377;
+    n >>= 8;
+    s = (s << 8) ^ crctab[(s >> 24) ^ c];
+  }
 
   return ~s;
 }
@@ -75,34 +75,32 @@ memcrc_r(uint32_t *state, const unsigned char *block, size_t block_len)
   register const unsigned char *b = block;
 
   for (; n > 0; --n)
-    {
-      c = (uint32_t) (*b++);
-      s = (s << 8) ^ crctab[(s >> 24) ^ c];
-    }
+  {
+    c = (uint32_t) (*b++);
+    s = (s << 8) ^ crctab[(s >> 24) ^ c];
+  }
 
   *state = s;
 }
 
 #ifdef WORDS_BIGENDIAN
-#define SWAP_CSUM(BITWIDTH, BYTEWIDTH, NACC)                               \
-  do                                                                       \
-    {                                                                      \
-      register const uint##BITWIDTH##_t *b = (uint##BITWIDTH##_t *) elems; \
-      for (size_t i = 0; i < num_elems; ++i)                               \
-        {                                                                  \
-          for (size_t aofs = NACC; aofs > 0; --aofs)                       \
-            {                                                              \
-              uint##BITWIDTH##_t accum = b[i + aofs - 1];                  \
-              for (size_t j = 0; j < BYTEWIDTH; ++j)                       \
-                {                                                          \
-                  uint32_t c = (uint32_t) (accum & UCHAR_MAX);             \
-                  s = (s << 8) ^ crctab[(s >> 24) ^ c];                    \
-                  accum >>= 8;                                             \
-                }                                                          \
-            }                                                              \
-        }                                                                  \
-    }                                                                      \
-  while (0)
+#define SWAP_CSUM(BITWIDTH, BYTEWIDTH, NACC)                             \
+  do {                                                                   \
+    register const uint##BITWIDTH##_t *b = (uint##BITWIDTH##_t *) elems; \
+    for (size_t i = 0; i < num_elems; ++i)                               \
+    {                                                                    \
+      for (size_t aofs = NACC; aofs > 0; --aofs)                         \
+      {                                                                  \
+        uint##BITWIDTH##_t accum = b[i + aofs - 1];                      \
+        for (size_t j = 0; j < BYTEWIDTH; ++j)                           \
+        {                                                                \
+          uint32_t c = (uint32_t) (accum & UCHAR_MAX);                   \
+          s = (s << 8) ^ crctab[(s >> 24) ^ c];                          \
+          accum >>= 8;                                                   \
+        }                                                                \
+      }                                                                  \
+    }                                                                    \
+  } while (0)
 #endif
 
 /**
@@ -119,13 +117,13 @@ memcrc_r_eswap(uint32_t *state, const unsigned char *elems, size_t num_elems, si
   register uint32_t s = *state;
 
   switch (elem_size)
-    {
+  {
     case 1: memcrc_r(state, elems, num_elems * elem_size); return;
     case 2: SWAP_CSUM(16, 2, 1); break;
     case 4: SWAP_CSUM(32, 4, 1); break;
     case 8: SWAP_CSUM(64, 8, 1); break;
     case 16: SWAP_CSUM(64, 8, 2); break;
-    }
+  }
   *state = s;
 #else
   memcrc_r(state, elems, num_elems * elem_size);
@@ -140,11 +138,11 @@ memcrc_finish(uint32_t *state, off_t total_size)
 
   /* Extend with the length of the string. */
   while (n != 0)
-    {
-      c = n & 0377;
-      n >>= 8;
-      s = (s << 8) ^ crctab[(s >> 24) ^ c];
-    }
+  {
+    c = n & 0377;
+    n >>= 8;
+    s = (s << 8) ^ crctab[(s >> 24) ^ c];
+  }
 
   return ~s;
 }
