@@ -183,21 +183,21 @@ static void
 file_list_delete(void)
 {
   if (_fileList)
-    {
-      free(_fileList);
-      _fileList = NULL;
-    }
+  {
+    free(_fileList);
+    _fileList = NULL;
+  }
 }
 
 static void
 file_init_pointer(void)
 {
   for (int i = 0; i < _file_max; i++)
-    {
-      _fileList[i].next = _fileList + i + 1;
-      _fileList[i].idx = i;
-      _fileList[i].ptr = 0;
-    }
+  {
+    _fileList[i].next = _fileList + i + 1;
+    _fileList[i].idx = i;
+    _fileList[i].ptr = 0;
+  }
 
   _fileList[_file_max - 1].next = 0;
 
@@ -212,11 +212,11 @@ file_to_pointer(int idx)
   FILE_INIT();
 
   if (idx >= 0 && idx < _file_max)
-    {
-      FILE_LOCK();
-      fileptr = _fileList[idx].ptr;
-      FILE_UNLOCK();
-    }
+  {
+    FILE_LOCK();
+    fileptr = _fileList[idx].ptr;
+    FILE_UNLOCK();
+  }
   else
     Error("file index %d undefined!", idx);
 
@@ -230,27 +230,27 @@ file_from_pointer(bfile_t *ptr)
   int idx = -1;
 
   if (ptr)
+  {
+    FILE_LOCK();
+
+    if (_fileAvail)
     {
-      FILE_LOCK();
+      filePtrToIdx *newptr = _fileAvail;
+      _fileAvail = _fileAvail->next;
+      newptr->next = 0;
+      idx = newptr->idx;
+      newptr->ptr = ptr;
 
-      if (_fileAvail)
-        {
-          filePtrToIdx *newptr = _fileAvail;
-          _fileAvail = _fileAvail->next;
-          newptr->next = 0;
-          idx = newptr->idx;
-          newptr->ptr = ptr;
-
-          if (FileDebug) Message("Pointer %p has idx %d from file list", ptr, idx);
-        }
-      else
-        {
-          Warning("Too many open files (limit is %d)!", _file_max);
-          idx = -2;
-        }
-
-      FILE_UNLOCK();
+      if (FileDebug) Message("Pointer %p has idx %d from file list", ptr, idx);
     }
+    else
+    {
+      Warning("Too many open files (limit is %d)!", _file_max);
+      idx = -2;
+    }
+
+    FILE_UNLOCK();
+  }
   else
     Error("Internal problem (pointer %p undefined)", ptr);
 
@@ -359,11 +359,11 @@ static void
 file_pointer_info(const char *caller, int fileID)
 {
   if (FileDebug)
-    {
-      fprintf(stdout, "%-18s : ", caller);
-      fprintf(stdout, "The fileID %d underlying pointer is not valid!", fileID);
-      fprintf(stdout, "\n");
-    }
+  {
+    fprintf(stdout, "%-18s : ", caller);
+    fprintf(stdout, "The fileID %d underlying pointer is not valid!", fileID);
+    fprintf(stdout, "\n");
+  }
 }
 
 int
@@ -373,14 +373,14 @@ fileSetBufferType(int fileID, int type)
 
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr)
+  {
+    switch (type)
     {
-      switch (type)
-        {
-        case FILE_BUFTYPE_STD:
-        case FILE_BUFTYPE_MMAP: fileptr->bufferType = type; break;
-        default: Error("File type %d not implemented!", type);
-        }
+      case FILE_BUFTYPE_STD:
+      case FILE_BUFTYPE_MMAP: fileptr->bufferType = type; break;
+      default: Error("File type %d not implemented!", type);
     }
+  }
 
 #ifndef HAVE_MMAP
   if (type == FILE_BUFTYPE_MMAP) ret = 1;
@@ -395,12 +395,12 @@ fileFlush(int fileID)
   int retval = 0;
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr)
-    {
-      FILE *fp = fileptr->fp;
-      retval = fflush(fp);
-      if (retval == 0) retval = fflush(fp);
-      if (retval != 0) retval = errno;
-    }
+  {
+    FILE *fp = fileptr->fp;
+    retval = fflush(fp);
+    if (retval == 0) retval = fflush(fp);
+    if (retval != 0) retval = errno;
+  }
 
   return retval;
 }
@@ -410,9 +410,9 @@ fileClearerr(int fileID)
 {
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr)
-    {
-      if (fileptr->mode != 'r') clearerr(fileptr->fp);
-    }
+  {
+    if (fileptr->mode != 'r') clearerr(fileptr->fp);
+  }
 }
 
 int
@@ -442,10 +442,7 @@ fileGetPos(int fileID)
   off_t filepos = 0;
 
   bfile_t *fileptr = file_to_pointer(fileID);
-  if (fileptr)
-    {
-      filepos = (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN) ? fileptr->position : ftell(fileptr->fp);
-    }
+  if (fileptr) { filepos = (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN) ? fileptr->position : ftell(fileptr->fp); }
 
   if (FileDebug) Message("Position %ld", filepos);
 
@@ -457,13 +454,13 @@ file_set_buffer_pos(bfile_t *fileptr)
 {
   off_t position = fileptr->position;
   if (position < fileptr->bufferStart || position > fileptr->bufferEnd)
-    {
-      fileptr->bufferPos = (fileptr->bufferType == FILE_BUFTYPE_STD) ? position : position - position % file_pagesize();
-      fileptr->bufferCnt = 0;
-      fileptr->bufferPtr = NULL;
+  {
+    fileptr->bufferPos = (fileptr->bufferType == FILE_BUFTYPE_STD) ? position : position - position % file_pagesize();
+    fileptr->bufferCnt = 0;
+    fileptr->bufferPtr = NULL;
 
-      return 1;
-    }
+    return 1;
+  }
 
   return 0;
 }
@@ -472,36 +469,36 @@ static void
 file_check_buffer_pos(bfile_t *fileptr)
 {
   if (fileptr->bufferPos != fileptr->bufferEnd + 1)
-    {
-      if (FileDebug) Message("Reset buffer pos from %ld to %ld", fileptr->bufferPos, fileptr->bufferEnd + 1);
+  {
+    if (FileDebug) Message("Reset buffer pos from %ld to %ld", fileptr->bufferPos, fileptr->bufferEnd + 1);
 
-      fileptr->bufferPos = fileptr->bufferEnd + 1;
-    }
+    fileptr->bufferPos = fileptr->bufferEnd + 1;
+  }
 }
 
 static void
 file_seek_buffer(bfile_t *fileptr, off_t offset, int whence)
 {
   if (whence == SEEK_SET)
+  {
+    fileptr->position = offset;
+    if (!file_set_buffer_pos(fileptr))
     {
-      fileptr->position = offset;
-      if (!file_set_buffer_pos(fileptr))
-        {
-          file_check_buffer_pos(fileptr);
-          fileptr->bufferCnt = (size_t) (fileptr->bufferEnd - fileptr->position) + 1;
-          fileptr->bufferPtr = fileptr->buffer + fileptr->position - fileptr->bufferStart;
-        }
+      file_check_buffer_pos(fileptr);
+      fileptr->bufferCnt = (size_t) (fileptr->bufferEnd - fileptr->position) + 1;
+      fileptr->bufferPtr = fileptr->buffer + fileptr->position - fileptr->bufferStart;
     }
+  }
   else if (whence == SEEK_CUR)
+  {
+    fileptr->position += offset;
+    if (!file_set_buffer_pos(fileptr))
     {
-      fileptr->position += offset;
-      if (!file_set_buffer_pos(fileptr))
-        {
-          file_check_buffer_pos(fileptr);
-          fileptr->bufferCnt -= (size_t) offset;
-          fileptr->bufferPtr += offset;
-        }
+      file_check_buffer_pos(fileptr);
+      fileptr->bufferCnt -= (size_t) offset;
+      fileptr->bufferPtr += offset;
     }
+  }
 }
 
 int
@@ -513,10 +510,10 @@ fileSetPos(int fileID, off_t offset, int whence)
 
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr == 0)
-    {
-      file_pointer_info(__func__, fileID);
-      return 1;
-    }
+  {
+    file_pointer_info(__func__, fileID);
+    return 1;
+  }
 
   if (whence != SEEK_SET && whence != SEEK_CUR) Error("Whence = %d not implemented", whence);
 
@@ -536,41 +533,41 @@ file_table_print(void)
   int lprintHeader = 1;
 
   for (int fileID = 0; fileID < _file_max; fileID++)
+  {
+    bfile_t *fileptr = file_to_pointer(fileID);
+    if (fileptr)
     {
-      bfile_t *fileptr = file_to_pointer(fileID);
-      if (fileptr)
-        {
-          if (lprintHeader)
-            {
-              fprintf(stderr, "\nFile table:\n");
-              fprintf(stderr, "+-----+---------+");
-              fprintf(stderr, "----------------------------------------------------+\n");
-              fprintf(stderr, "|  ID |  Mode   |");
-              fprintf(stderr, "  Name                                              |\n");
-              fprintf(stderr, "+-----+---------+");
-              fprintf(stderr, "----------------------------------------------------+\n");
-              lprintHeader = 0;
-            }
+      if (lprintHeader)
+      {
+        fprintf(stderr, "\nFile table:\n");
+        fprintf(stderr, "+-----+---------+");
+        fprintf(stderr, "----------------------------------------------------+\n");
+        fprintf(stderr, "|  ID |  Mode   |");
+        fprintf(stderr, "  Name                                              |\n");
+        fprintf(stderr, "+-----+---------+");
+        fprintf(stderr, "----------------------------------------------------+\n");
+        lprintHeader = 0;
+      }
 
-          fprintf(stderr, "| %3d | ", fileID);
+      fprintf(stderr, "| %3d | ", fileID);
 
-          switch (fileptr->mode)
-            {
-            case 'r': fprintf(stderr, "read   "); break;
-            case 'w': fprintf(stderr, "write  "); break;
-            case 'a': fprintf(stderr, "append "); break;
-            default: fprintf(stderr, "unknown");
-            }
+      switch (fileptr->mode)
+      {
+        case 'r': fprintf(stderr, "read   "); break;
+        case 'w': fprintf(stderr, "write  "); break;
+        case 'a': fprintf(stderr, "append "); break;
+        default: fprintf(stderr, "unknown");
+      }
 
-          fprintf(stderr, " | %-51s|\n", fileptr->name);
-        }
+      fprintf(stderr, " | %-51s|\n", fileptr->name);
     }
+  }
 
   if (lprintHeader == 0)
-    {
-      fprintf(stderr, "+-----+---------+");
-      fprintf(stderr, "----------------------------------------------------+\n");
-    }
+  {
+    fprintf(stderr, "+-----+---------+");
+    fprintf(stderr, "----------------------------------------------------+\n");
+  }
 }
 
 char *
@@ -593,31 +590,31 @@ file_getenv(const char *envName)
   long envValue = -1;
   char *envString = getenv(envName);
   if (envString)
+  {
+    long fact = 1;
+    for (int i = 0; i < (int) strlen(envString); i++)
     {
-      long fact = 1;
-      for (int i = 0; i < (int) strlen(envString); i++)
+      if (!isdigit((int) envString[i]))
+      {
+        switch (tolower((int) envString[i]))
         {
-          if (!isdigit((int) envString[i]))
-            {
-              switch (tolower((int) envString[i]))
-                {
-                case 'k': fact = 1024; break;
-                case 'm': fact = 1048576; break;
-                case 'g': fact = 1073741824; break;
-                default:
-                  fact = 0;
-                  Warning("Invalid number string in %s: %s", envName, envString);
-                  Warning("%s must comprise only digits [0-9].", envName);
-                }
-              break;
-            }
+          case 'k': fact = 1024; break;
+          case 'm': fact = 1048576; break;
+          case 'g': fact = 1073741824; break;
+          default:
+            fact = 0;
+            Warning("Invalid number string in %s: %s", envName, envString);
+            Warning("%s must comprise only digits [0-9].", envName);
         }
-
-      if (fact) envValue = fact * atol(envString);
-
-      if (FileDebug) Message("Set %s to %ld", envName, envValue);
+        break;
+      }
     }
 
+    if (fact) envValue = fact * atol(envString);
+
+    if (FileDebug) Message("Set %s to %ld", envName, envValue);
+  }
+
   return envValue;
 }
 
@@ -640,23 +637,23 @@ file_initialize(void)
   if (value >= 0)
     FileBufferSizeEnv = value;
   else
-    {
-      value = file_getenv("GRIB_API_IO_BUFFER_SIZE");
-      if (value >= 0) FileBufferSizeEnv = value;
-    }
+  {
+    value = file_getenv("GRIB_API_IO_BUFFER_SIZE");
+    if (value >= 0) FileBufferSizeEnv = value;
+  }
 
   if (FileInfo) fprintf(stderr, "FILE_BUFSIZE = %ld\n", FileBufferSizeEnv);
 
   value = file_getenv("FILE_TYPE_READ");
   if (value > 0)
+  {
+    switch (value)
     {
-      switch (value)
-        {
-        case FILE_TYPE_OPEN:
-        case FILE_TYPE_FOPEN: FileTypeRead = (int) value; break;
-        default: Warning("File type %ld not implemented!", value);
-        }
+      case FILE_TYPE_OPEN:
+      case FILE_TYPE_FOPEN: FileTypeRead = (int) value; break;
+      default: Warning("File type %ld not implemented!", value);
     }
+  }
 
   if (FileInfo)
     fprintf(stderr, "FILE_TYPE_READ = %d [%d:%s  %d:%s]\n", FileTypeRead, FILE_TYPE_OPEN, ftname[FILE_TYPE_OPEN], FILE_TYPE_FOPEN,
@@ -664,14 +661,14 @@ file_initialize(void)
 
   value = file_getenv("FILE_TYPE_WRITE");
   if (value > 0)
+  {
+    switch (value)
     {
-      switch (value)
-        {
-        case FILE_TYPE_OPEN:
-        case FILE_TYPE_FOPEN: FileTypeWrite = (int) value; break;
-        default: Warning("File type %ld not implemented!", value);
-        }
+      case FILE_TYPE_OPEN:
+      case FILE_TYPE_FOPEN: FileTypeWrite = (int) value; break;
+      default: Warning("File type %ld not implemented!", value);
     }
+  }
 
   if (FileInfo)
     fprintf(stderr, "FILE_TYPE_WRITE = %d [%d:%s  %d:%s]\n", FileTypeWrite, FILE_TYPE_OPEN, ftname[FILE_TYPE_OPEN], FILE_TYPE_FOPEN,
@@ -682,29 +679,29 @@ file_initialize(void)
 #endif
   char *envString = getenv("FILE_FLAG_WRITE");
   if (envString)
-    {
+  {
 #ifdef O_NONBLOCK
-      if (strcmp(envString, "NONBLOCK") == 0) FileFlagWrite = O_NONBLOCK;
+    if (strcmp(envString, "NONBLOCK") == 0) FileFlagWrite = O_NONBLOCK;
 #endif
-    }
+  }
 
   value = file_getenv("FILE_BUFTYPE");
 #ifndef HAVE_MMAP
   if (value == FILE_BUFTYPE_MMAP)
-    {
-      Warning("MMAP not available!");
-      value = 0;
-    }
+  {
+    Warning("MMAP not available!");
+    value = 0;
+  }
 #endif
   if (value > 0)
+  {
+    switch (value)
     {
-      switch (value)
-        {
-        case FILE_BUFTYPE_STD:
-        case FILE_BUFTYPE_MMAP: FileBufferTypeEnv = (int) value; break;
-        default: Warning("File buffer type %ld not implemented!", value);
-        }
+      case FILE_BUFTYPE_STD:
+      case FILE_BUFTYPE_MMAP: FileBufferTypeEnv = (int) value; break;
+      default: Warning("File buffer type %ld not implemented!", value);
     }
+  }
 
   if (FileInfo)
     fprintf(stderr, "FILE_BUFTYPE = %d [%d:%s  %d:%s]\n", FileBufferTypeEnv, FILE_BUFTYPE_STD, fbtname[FILE_BUFTYPE_STD],
@@ -732,10 +729,10 @@ file_get_buffersize(bfile_t *fileptr)
   else if (fileptr->bufferSize > 0)
     buffersize = fileptr->bufferSize;
   else
-    {
-      buffersize = fileptr->blockSize * 4;
-      if (buffersize < FileBufferSizeMin) buffersize = FileBufferSizeMin;
-    }
+  {
+    buffersize = fileptr->blockSize * 4;
+    if (buffersize < FileBufferSizeMin) buffersize = FileBufferSizeMin;
+  }
 
   return buffersize;
 }
@@ -746,41 +743,41 @@ file_set_buffer(bfile_t *fileptr)
   size_t buffersize = 0;
 
   if (fileptr->mode == 'r')
-    {
-      if (FileBufferTypeEnv)
-        fileptr->bufferType = FileBufferTypeEnv;
-      else if (fileptr->bufferType == 0)
-        fileptr->bufferType = FILE_BUFTYPE_STD;
-
-      buffersize = file_get_buffersize(fileptr);
-
-      if ((size_t) fileptr->size < buffersize) buffersize = (size_t) fileptr->size;
-
-      if (fileptr->bufferType == FILE_BUFTYPE_MMAP)
-        {
-          size_t blocksize = (size_t) file_pagesize();
-          size_t minblocksize = 4 * blocksize;
-          buffersize = buffersize - buffersize % minblocksize;
-
-          if (buffersize < (size_t) fileptr->size && buffersize < minblocksize) buffersize = minblocksize;
-        }
-
-      if (buffersize == 0) buffersize = 1;
-    }
-  else
-    {
+  {
+    if (FileBufferTypeEnv)
+      fileptr->bufferType = FileBufferTypeEnv;
+    else if (fileptr->bufferType == 0)
       fileptr->bufferType = FILE_BUFTYPE_STD;
-      buffersize = file_get_buffersize(fileptr);
+
+    buffersize = file_get_buffersize(fileptr);
+
+    if ((size_t) fileptr->size < buffersize) buffersize = (size_t) fileptr->size;
+
+    if (fileptr->bufferType == FILE_BUFTYPE_MMAP)
+    {
+      size_t blocksize = (size_t) file_pagesize();
+      size_t minblocksize = 4 * blocksize;
+      buffersize = buffersize - buffersize % minblocksize;
+
+      if (buffersize < (size_t) fileptr->size && buffersize < minblocksize) buffersize = minblocksize;
     }
 
+    if (buffersize == 0) buffersize = 1;
+  }
+  else
+  {
+    fileptr->bufferType = FILE_BUFTYPE_STD;
+    buffersize = file_get_buffersize(fileptr);
+  }
+
   if (fileptr->bufferType == FILE_BUFTYPE_STD || fileptr->type == FILE_TYPE_FOPEN)
+  {
+    if (buffersize > 0)
     {
-      if (buffersize > 0)
-        {
-          fileptr->buffer = (char *) malloc(buffersize);
-          if (fileptr->buffer == NULL) SysError("Allocation of file buffer failed!");
-        }
+      fileptr->buffer = (char *) malloc(buffersize);
+      if (fileptr->buffer == NULL) SysError("Allocation of file buffer failed!");
     }
+  }
 
   if (fileptr->type == FILE_TYPE_FOPEN)
     if (setvbuf(fileptr->fp, fileptr->buffer, fileptr->buffer ? _IOFBF : _IONBF, buffersize)) SysError("setvbuf failed!");
@@ -806,51 +803,48 @@ file_fill_buffer(bfile_t *fileptr)
 
 #ifdef HAVE_MMAP
   if (fileptr->bufferType == FILE_BUFTYPE_MMAP)
+  {
+    if (fileptr->bufferPos >= fileptr->size) { nread = 0; }
+    else
     {
-      if (fileptr->bufferPos >= fileptr->size)
-        {
-          nread = 0;
-        }
-      else
-        {
 #ifdef CDI
-          xassert(fileptr->bufferSize <= SSIZE_MAX);
+      xassert(fileptr->bufferSize <= SSIZE_MAX);
 #endif
-          nread = (ssize_t) fileptr->bufferSize;
-          if ((nread + fileptr->bufferPos) > fileptr->size) nread = fileptr->size - fileptr->bufferPos;
+      nread = (ssize_t) fileptr->bufferSize;
+      if ((nread + fileptr->bufferPos) > fileptr->size) nread = fileptr->size - fileptr->bufferPos;
 
-          if (fileptr->buffer)
-            {
-              int ret = munmap(fileptr->buffer, fileptr->mappedSize);
-              if (ret == -1) SysError("munmap error for read %s", fileptr->name);
-              fileptr->buffer = NULL;
-            }
+      if (fileptr->buffer)
+      {
+        int ret = munmap(fileptr->buffer, fileptr->mappedSize);
+        if (ret == -1) SysError("munmap error for read %s", fileptr->name);
+        fileptr->buffer = NULL;
+      }
 
-          fileptr->mappedSize = (size_t) nread;
+      fileptr->mappedSize = (size_t) nread;
 
-          fileptr->buffer = (char *) mmap(NULL, (size_t) nread, PROT_READ, MAP_PRIVATE, fd, fileptr->bufferPos);
+      fileptr->buffer = (char *) mmap(NULL, (size_t) nread, PROT_READ, MAP_PRIVATE, fd, fileptr->bufferPos);
 
-          if (fileptr->buffer == MAP_FAILED) SysError("mmap error for read %s", fileptr->name);
+      if (fileptr->buffer == MAP_FAILED) SysError("mmap error for read %s", fileptr->name);
 
-          offset = fileptr->position - fileptr->bufferPos;
-        }
+      offset = fileptr->position - fileptr->bufferPos;
     }
+  }
   else
 #endif
-    {
-      off_t retseek = lseek(fileptr->fd, fileptr->bufferPos, SEEK_SET);
-      if (retseek == (off_t) -1) SysError("lseek error at pos %ld file %s", (long) fileptr->bufferPos, fileptr->name);
+  {
+    off_t retseek = lseek(fileptr->fd, fileptr->bufferPos, SEEK_SET);
+    if (retseek == (off_t) -1) SysError("lseek error at pos %ld file %s", (long) fileptr->bufferPos, fileptr->name);
 
-      nread = read(fd, fileptr->buffer, fileptr->bufferSize);
-      if (nread > 0) offset = fileptr->position - fileptr->bufferPos;
-    }
+    nread = read(fd, fileptr->buffer, fileptr->bufferSize);
+    if (nread > 0) offset = fileptr->position - fileptr->bufferPos;
+  }
 
   if (nread <= 0)
-    {
-      fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
-      fileptr->bufferCnt = 0;
-      return EOF;
-    }
+  {
+    fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
+    fileptr->bufferCnt = 0;
+    return EOF;
+  }
 
   fileptr->bufferPtr = fileptr->buffer;
   fileptr->bufferCnt = (size_t) nread;
@@ -860,23 +854,23 @@ file_fill_buffer(bfile_t *fileptr)
   fileptr->bufferEnd = fileptr->bufferPos - 1;
 
   if (FileDebug)
-    {
-      Message("fileID = %d  Val     = %d", fileptr->self, (int) fileptr->buffer[0]);
-      Message("fileID = %d  Start   = %ld", fileptr->self, fileptr->bufferStart);
-      Message("fileID = %d  End     = %ld", fileptr->self, fileptr->bufferEnd);
-      Message("fileID = %d  nread   = %ld", fileptr->self, nread);
-      Message("fileID = %d  offset  = %ld", fileptr->self, offset);
-      Message("fileID = %d  Pos     = %ld", fileptr->self, fileptr->bufferPos);
-      Message("fileID = %d  postion = %ld", fileptr->self, fileptr->position);
-    }
+  {
+    Message("fileID = %d  Val     = %d", fileptr->self, (int) fileptr->buffer[0]);
+    Message("fileID = %d  Start   = %ld", fileptr->self, fileptr->bufferStart);
+    Message("fileID = %d  End     = %ld", fileptr->self, fileptr->bufferEnd);
+    Message("fileID = %d  nread   = %ld", fileptr->self, nread);
+    Message("fileID = %d  offset  = %ld", fileptr->self, offset);
+    Message("fileID = %d  Pos     = %ld", fileptr->self, fileptr->bufferPos);
+    Message("fileID = %d  postion = %ld", fileptr->self, fileptr->position);
+  }
 
   if (offset > 0)
-    {
-      if (offset > nread) Error("Internal problem with buffer handling. nread = %d offset = %d", nread, offset);
+  {
+    if (offset > nread) Error("Internal problem with buffer handling. nread = %d offset = %d", nread, offset);
 
-      fileptr->bufferPtr += offset;
-      fileptr->bufferCnt -= (size_t) offset;
-    }
+    fileptr->bufferPtr += offset;
+    fileptr->bufferCnt -= (size_t) offset;
+  }
 
   fileptr->bufferNumFill++;
 
@@ -891,19 +885,19 @@ file_copy_from_buffer(bfile_t *fileptr, void *ptr, size_t size)
   if (fileptr->bufferCnt < size) Error("Buffer too small. bufferCnt = %d", fileptr->bufferCnt);
 
   if (size == 1)
-    {
-      ((char *) ptr)[0] = fileptr->bufferPtr[0];
+  {
+    ((char *) ptr)[0] = fileptr->bufferPtr[0];
 
-      fileptr->bufferPtr++;
-      fileptr->bufferCnt--;
-    }
+    fileptr->bufferPtr++;
+    fileptr->bufferCnt--;
+  }
   else
-    {
-      memcpy(ptr, fileptr->bufferPtr, size);
+  {
+    memcpy(ptr, fileptr->bufferPtr, size);
 
-      fileptr->bufferPtr += size;
-      fileptr->bufferCnt -= size;
-    }
+    fileptr->bufferPtr += size;
+    fileptr->bufferCnt -= size;
+  }
 }
 
 static size_t
@@ -919,15 +913,15 @@ file_read_from_buffer(bfile_t *fileptr, void *ptr, size_t size)
   size_t rsize = size;
 
   while (fileptr->bufferCnt < rsize)
-    {
-      nread = fileptr->bufferCnt;
-      // fprintf(stderr, "rsize = %d nread = %d\n", (int) rsize, (int) nread);
-      if (nread > (size_t) 0) file_copy_from_buffer(fileptr, (char *) ptr + offset, nread);
-      offset += nread;
-      rsize = (nread < rsize) ? rsize - nread : 0;
+  {
+    nread = fileptr->bufferCnt;
+    // fprintf(stderr, "rsize = %d nread = %d\n", (int) rsize, (int) nread);
+    if (nread > (size_t) 0) file_copy_from_buffer(fileptr, (char *) ptr + offset, nread);
+    offset += nread;
+    rsize = (nread < rsize) ? rsize - nread : 0;
 
-      if (file_fill_buffer(fileptr) == EOF) break;
-    }
+    if (file_fill_buffer(fileptr) == EOF) break;
+  }
 
   nread = size - offset;
 
@@ -975,7 +969,7 @@ fileOpen_serial(const char *filename, const char *mode)
   int fmode = tolower((int) mode[0]);
 
   switch (fmode)
-    {
+  {
     case 'r':
       if (FileTypeRead == FILE_TYPE_FOPEN)
         fp = fopen(filename, "rb");
@@ -991,57 +985,57 @@ fileOpen_serial(const char *filename, const char *mode)
       break;
     case 'a': fp = fopen(filename, "ab"); break;
     default: Error("Mode %c unexpected!", fmode);
-    }
+  }
 
   if (FileDebug && fp == NULL && fd == -1) Message("Open failed on %s mode %c errno %d", filename, fmode, errno);
 
   if (fp)
-    {
-      if (stat(filename, &filestat) != 0) return fileID;
+  {
+    if (stat(filename, &filestat) != 0) return fileID;
 
-      fileptr = file_new_entry();
-      if (fileptr)
-        {
-          fileID = fileptr->self;
-          fileptr->fp = fp;
-        }
+    fileptr = file_new_entry();
+    if (fileptr)
+    {
+      fileID = fileptr->self;
+      fileptr->fp = fp;
     }
+  }
   else if (fd >= 0)
-    {
-      if (fstat(fd, &filestat) != 0) return fileID;
+  {
+    if (fstat(fd, &filestat) != 0) return fileID;
 
-      fileptr = file_new_entry();
-      if (fileptr)
-        {
-          fileID = fileptr->self;
-          fileptr->fd = fd;
-        }
+    fileptr = file_new_entry();
+    if (fileptr)
+    {
+      fileID = fileptr->self;
+      fileptr->fd = fd;
     }
+  }
 
   if (fileID >= 0)
-    {
-      fileptr->mode = fmode;
-      fileptr->name = strdup(filename);
+  {
+    fileptr->mode = fmode;
+    fileptr->name = strdup(filename);
 
 #ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
-      fileptr->blockSize = (size_t) filestat.st_blksize;
+    fileptr->blockSize = (size_t) filestat.st_blksize;
 #else
-      fileptr->blockSize = (size_t) 4096;
+    fileptr->blockSize = (size_t) 4096;
 #endif
 
-      // clang-format off
+    // clang-format off
       if      (fmode == 'r') fileptr->type = FileTypeRead;
       else if (fmode == 'w') fileptr->type = FileTypeWrite;
       else                   fileptr->type = FILE_TYPE_FOPEN;
-      // clang-format on
+    // clang-format on
 
-      if (fmode == 'r') fileptr->size = filestat.st_size;
+    if (fmode == 'r') fileptr->size = filestat.st_size;
 
-      // if (fileptr->type == FILE_TYPE_FOPEN) file_set_buffer(fileptr);
-      file_set_buffer(fileptr);
+    // if (fileptr->type == FILE_TYPE_FOPEN) file_set_buffer(fileptr);
+    file_set_buffer(fileptr);
 
-      if (FileDebug) Message("File %s opened with ID %d", filename, fileID);
-    }
+    if (FileDebug) Message("File %s opened with ID %d", filename, fileID);
+  }
 
   return fileID;
 }
@@ -1065,82 +1059,82 @@ fileClose_serial(int fileID)
 
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr == NULL)
-    {
-      file_pointer_info(__func__, fileID);
-      return 1;
-    }
+  {
+    file_pointer_info(__func__, fileID);
+    return 1;
+  }
 
   const char *name = fileptr->name;
 
   if (FileDebug) Message("fileID = %d  filename = %s", fileID, name);
 
   if (FileInfo)
+  {
+    fprintf(stderr, "____________________________________________\n");
+    fprintf(stderr, " file ID          : %d\n", fileID);
+    fprintf(stderr, " file name        : %s\n", fileptr->name);
+    fprintf(stderr, " file type        : %d (%s)\n", fileptr->type, ftname[fileptr->type]);
+
+    if (fileptr->type == FILE_TYPE_FOPEN)
+      fprintf(stderr, " file pointer     : %p\n", (void *) fileptr->fp);
+    else
     {
-      fprintf(stderr, "____________________________________________\n");
-      fprintf(stderr, " file ID          : %d\n", fileID);
-      fprintf(stderr, " file name        : %s\n", fileptr->name);
-      fprintf(stderr, " file type        : %d (%s)\n", fileptr->type, ftname[fileptr->type]);
-
-      if (fileptr->type == FILE_TYPE_FOPEN)
-        fprintf(stderr, " file pointer     : %p\n", (void *) fileptr->fp);
-      else
-        {
-          fprintf(stderr, " file descriptor  : %d\n", fileptr->fd);
-          fprintf(stderr, " file flag        : %d\n", FileFlagWrite);
-        }
-      fprintf(stderr, " file mode        : %c\n", fileptr->mode);
-
-      if (sizeof(off_t) > sizeof(long))
-        {
-#ifdef _WIN32
-          fprintf(stderr, " file size        : %I64d\n", (long long) fileptr->size);
-          if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %I64d\n", (long long) fileptr->position);
-          fprintf(stderr, " bytes transfered : %I64d\n", (long long) fileptr->byteTrans);
-#else
-          fprintf(stderr, " file size        : %lld\n", (long long) fileptr->size);
-          if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %lld\n", (long long) fileptr->position);
-          fprintf(stderr, " bytes transfered : %lld\n", (long long) fileptr->byteTrans);
-#endif
-        }
-      else
-        {
-          fprintf(stderr, " file size        : %ld\n", (long) fileptr->size);
-          if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %ld\n", (long) fileptr->position);
-          fprintf(stderr, " bytes transfered : %ld\n", (long) fileptr->byteTrans);
-        }
-
-      if (fileptr->time_in_sec > 0) rout = (double) fileptr->byteTrans / (1024. * 1024. * fileptr->time_in_sec);
-
-      fprintf(stderr, " wall time [s]    : %.2f\n", fileptr->time_in_sec);
-      fprintf(stderr, " data rate [MB/s] : %.1f\n", rout);
-
-      fprintf(stderr, " file access      : %ld\n", fileptr->access);
-      if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN)
-        {
-          fprintf(stderr, " buffer type      : %d (%s)\n", fileptr->bufferType, fbtname[fileptr->bufferType]);
-          fprintf(stderr, " num buffer fill  : %ld\n", fileptr->bufferNumFill);
-        }
-      fprintf(stderr, " buffer size      : %lu\n", (unsigned long) fileptr->bufferSize);
-      fprintf(stderr, " block size       : %lu\n", (unsigned long) fileptr->blockSize);
-      fprintf(stderr, " page size        : %d\n", file_pagesize());
-      fprintf(stderr, "--------------------------------------------\n");
+      fprintf(stderr, " file descriptor  : %d\n", fileptr->fd);
+      fprintf(stderr, " file flag        : %d\n", FileFlagWrite);
     }
+    fprintf(stderr, " file mode        : %c\n", fileptr->mode);
+
+    if (sizeof(off_t) > sizeof(long))
+    {
+#ifdef _WIN32
+      fprintf(stderr, " file size        : %I64d\n", (long long) fileptr->size);
+      if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %I64d\n", (long long) fileptr->position);
+      fprintf(stderr, " bytes transfered : %I64d\n", (long long) fileptr->byteTrans);
+#else
+      fprintf(stderr, " file size        : %lld\n", (long long) fileptr->size);
+      if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %lld\n", (long long) fileptr->position);
+      fprintf(stderr, " bytes transfered : %lld\n", (long long) fileptr->byteTrans);
+#endif
+    }
+    else
+    {
+      fprintf(stderr, " file size        : %ld\n", (long) fileptr->size);
+      if (fileptr->type == FILE_TYPE_OPEN) fprintf(stderr, " file position    : %ld\n", (long) fileptr->position);
+      fprintf(stderr, " bytes transfered : %ld\n", (long) fileptr->byteTrans);
+    }
+
+    if (fileptr->time_in_sec > 0) rout = (double) fileptr->byteTrans / (1024. * 1024. * fileptr->time_in_sec);
+
+    fprintf(stderr, " wall time [s]    : %.2f\n", fileptr->time_in_sec);
+    fprintf(stderr, " data rate [MB/s] : %.1f\n", rout);
+
+    fprintf(stderr, " file access      : %ld\n", fileptr->access);
+    if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN)
+    {
+      fprintf(stderr, " buffer type      : %d (%s)\n", fileptr->bufferType, fbtname[fileptr->bufferType]);
+      fprintf(stderr, " num buffer fill  : %ld\n", fileptr->bufferNumFill);
+    }
+    fprintf(stderr, " buffer size      : %lu\n", (unsigned long) fileptr->bufferSize);
+    fprintf(stderr, " block size       : %lu\n", (unsigned long) fileptr->blockSize);
+    fprintf(stderr, " page size        : %d\n", file_pagesize());
+    fprintf(stderr, "--------------------------------------------\n");
+  }
 
   if (fileptr->type == FILE_TYPE_FOPEN)
-    {
-      if (fclose(fileptr->fp) == EOF) SysError("EOF returned for close of %s!", name);
-    }
+  {
+    if (fclose(fileptr->fp) == EOF) SysError("EOF returned for close of %s!", name);
+  }
   else
-    {
+  {
 #ifdef HAVE_MMAP
-      if (fileptr->buffer && fileptr->mappedSize)
-        {
-          if (munmap(fileptr->buffer, fileptr->mappedSize) == -1) SysError("munmap error for close %s", fileptr->name);
-          fileptr->buffer = NULL;
-        }
-#endif
-      if (close(fileptr->fd) == -1) SysError("EOF returned for close of %s!", name);
+    if (fileptr->buffer && fileptr->mappedSize)
+    {
+      if (munmap(fileptr->buffer, fileptr->mappedSize) == -1) SysError("munmap error for close %s", fileptr->name);
+      fileptr->buffer = NULL;
     }
+#endif
+    if (close(fileptr->fd) == -1) SysError("EOF returned for close of %s!", name);
+  }
 
   if (fileptr->name) free((void *) fileptr->name);
   if (fileptr->buffer) free((void *) fileptr->buffer);
@@ -1157,32 +1151,32 @@ filePtrGetc(void *vfileptr)
 
   bfile_t *fileptr = (bfile_t *) vfileptr;
   if (fileptr)
+  {
+    if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN)
     {
-      if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN)
-        {
-          int fillret = (fileptr->bufferCnt == 0) ? file_fill_buffer(fileptr) : 0;
-          if (fillret >= 0)
-            {
-              ivalue = (unsigned char) *fileptr->bufferPtr++;
-              fileptr->bufferCnt--;
-              fileptr->position++;
+      int fillret = (fileptr->bufferCnt == 0) ? file_fill_buffer(fileptr) : 0;
+      if (fillret >= 0)
+      {
+        ivalue = (unsigned char) *fileptr->bufferPtr++;
+        fileptr->bufferCnt--;
+        fileptr->position++;
 
-              fileptr->byteTrans++;
-              fileptr->access++;
-            }
-        }
-      else
-        {
-          ivalue = fgetc(fileptr->fp);
-          if (ivalue >= 0)
-            {
-              fileptr->byteTrans++;
-              fileptr->access++;
-            }
-          else
-            fileptr->flag |= FILE_EOF;
-        }
+        fileptr->byteTrans++;
+        fileptr->access++;
+      }
     }
+    else
+    {
+      ivalue = fgetc(fileptr->fp);
+      if (ivalue >= 0)
+      {
+        fileptr->byteTrans++;
+        fileptr->access++;
+      }
+      else
+        fileptr->flag |= FILE_EOF;
+    }
+  }
 
   return ivalue;
 }
@@ -1201,22 +1195,19 @@ filePtrRead(void *vfileptr, void *restrict ptr, size_t size)
 
   bfile_t *fileptr = (bfile_t *) vfileptr;
   if (fileptr)
+  {
+    if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN) { nread = file_read_from_buffer(fileptr, ptr, size); }
+    else
     {
-      if (fileptr->mode == 'r' && fileptr->type == FILE_TYPE_OPEN)
-        {
-          nread = file_read_from_buffer(fileptr, ptr, size);
-        }
-      else
-        {
-          nread = fread(ptr, 1, size, fileptr->fp);
-          if (nread != size) fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
-        }
-
-      fileptr->position += (off_t) nread;
-      fileptr->byteTrans += (off_t) nread;
-      fileptr->access++;
+      nread = fread(ptr, 1, size, fileptr->fp);
+      if (nread != size) fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
     }
 
+    fileptr->position += (off_t) nread;
+    fileptr->byteTrans += (off_t) nread;
+    fileptr->access++;
+  }
+
   if (FileDebug) Message("size %ld  nread %ld", size, nread);
 
   return nread;
@@ -1229,28 +1220,25 @@ fileRead(int fileID, void *restrict ptr, size_t size)
 
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr)
+  {
+    double t_begin = 0.0;
+
+    if (FileInfo) t_begin = file_time();
+
+    if (fileptr->type == FILE_TYPE_OPEN) { nread = file_read_from_buffer(fileptr, ptr, size); }
+    else
     {
-      double t_begin = 0.0;
-
-      if (FileInfo) t_begin = file_time();
-
-      if (fileptr->type == FILE_TYPE_OPEN)
-        {
-          nread = file_read_from_buffer(fileptr, ptr, size);
-        }
-      else
-        {
-          nread = fread(ptr, 1, size, fileptr->fp);
-          if (nread != size) fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
-        }
-
-      if (FileInfo) fileptr->time_in_sec += file_time() - t_begin;
-
-      fileptr->position += (off_t) nread;
-      fileptr->byteTrans += (off_t) nread;
-      fileptr->access++;
+      nread = fread(ptr, 1, size, fileptr->fp);
+      if (nread != size) fileptr->flag |= (nread == 0) ? FILE_EOF : FILE_ERROR;
     }
 
+    if (FileInfo) fileptr->time_in_sec += file_time() - t_begin;
+
+    fileptr->position += (off_t) nread;
+    fileptr->byteTrans += (off_t) nread;
+    fileptr->access++;
+  }
+
   if (FileDebug) Message("size %ld  nread %ld", size, nread);
 
   return nread;
@@ -1263,29 +1251,26 @@ fileWrite(int fileID, const void *restrict ptr, size_t size)
 
   bfile_t *fileptr = file_to_pointer(fileID);
   if (fileptr)
+  {
+    double t_begin = 0.0;
+
+    if (FileInfo) t_begin = file_time();
+
+    if (fileptr->type == FILE_TYPE_FOPEN) { nwrite = fwrite(ptr, 1, size, fileptr->fp); }
+    else
     {
-      double t_begin = 0.0;
-
-      if (FileInfo) t_begin = file_time();
-
-      if (fileptr->type == FILE_TYPE_FOPEN)
-        {
-          nwrite = fwrite(ptr, 1, size, fileptr->fp);
-        }
-      else
-        {
-          ssize_t temp = write(fileptr->fd, ptr, size);
-          if (temp == -1) perror("error writing to file");
-          nwrite = (temp == -1) ? 0 : (size_t) temp;
-        }
-
-      if (FileInfo) fileptr->time_in_sec += file_time() - t_begin;
-
-      fileptr->position += (off_t) nwrite;
-      fileptr->byteTrans += (off_t) nwrite;
-      fileptr->access++;
+      ssize_t temp = write(fileptr->fd, ptr, size);
+      if (temp == -1) perror("error writing to file");
+      nwrite = (temp == -1) ? 0 : (size_t) temp;
     }
 
+    if (FileInfo) fileptr->time_in_sec += file_time() - t_begin;
+
+    fileptr->position += (off_t) nwrite;
+    fileptr->byteTrans += (off_t) nwrite;
+    fileptr->access++;
+  }
+
   return nwrite;
 }
 /*
