@@ -1,9 +1,7 @@
 #ifndef MODEL_H
 #define MODEL_H
 
-int
-modelUnpack(void *buf, int size, int *position,
-            int originNamespace, void *context, int force_id);
+int modelUnpack(void *buf, int size, int *position, int originNamespace, void *context, int force_id);
 
 void modelDefaultEntries(void);
 
