@@ -533,7 +533,6 @@ cdfPostDefActionAddPut1Int(struct cdfPostDefActionList **list_, int fileID, int
 static void
 cdfGridCompress(int fileID, int ncvarid, size_t gridsize, int filetype, int comptype, size_t *chunks)
 {
-#ifdef HAVE_NETCDF4
   if (gridsize >= 32 && comptype == CDI_COMPRESS_ZIP
       && (filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C || filetype == CDI_FILETYPE_NCZARR))
   {
@@ -541,7 +540,6 @@ cdfGridCompress(int fileID, int ncvarid, size_t gridsize, int filetype, int comp
     int shuffle = 1, compLevel = 1;
     cdfDefVarDeflate(fileID, ncvarid, shuffle, compLevel);
   }
-#endif
 }
 
 static struct cdfPostDefActionList *
@@ -1612,7 +1610,7 @@ cdfDefZaxisChar(stream_t *streamptr, int zaxisID, char *axisname, int *dimID, si
   int length = sizeof(dimname);
   cdiInqKeyString(zaxisID, CDI_GLOBAL, CDI_KEY_DIMNAME, dimname, &length);
   *dimID = checkDimName(fileID, dimlen, dimname);
-  if (dimlen <= 0) Error("No strings delivered for a character axis.");
+  if (dimlen == 0) Error("No strings delivered for a character axis.");
   if (dimname[0] == 0)
   {
     memcpy(dimname, "area_type", 10);
@@ -1827,8 +1825,23 @@ cdfDefZaxis(stream_t *streamptr, int zaxisID)
 static struct cdfPostDefActionList *
 cdf_def_grid_indices(stream_t *streamptr, int gridID, int gridIndex)
 {
-#ifdef HAVE_NETCDF4
   int fileID = streamptr->fileID;
+
+  int dataType = CDI_UNDEFID;
+  cdiInqKeyInt(gridID, CDI_GLOBAL, CDI_KEY_DATATYPE, &dataType);
+  nc_type xtype = (dataType == CDI_DATATYPE_INT32) ? NC_INT : NC_INT64;
+
+  if (xtype == NC_INT64)
+  {
+    int fileFormat;
+    int status = nc_inq_format(fileID, &fileFormat);
+    if (status == NC_NOERR && fileFormat != NC_FORMAT_NETCDF4 && fileFormat != NC_FORMAT_NETCDF4_CLASSIC)
+    {
+      Warning("The grid cell indices couldn't be stored because 64-bit integer is not supported by data format!");
+      return NULL;
+    }
+  }
+
   SizeType dimlen = gridInqSize(gridID);
 
   bool switchNCMode = (streamptr->ncmode == 2);
@@ -1847,11 +1860,6 @@ cdf_def_grid_indices(stream_t *streamptr, int gridID, int gridIndex)
   int dimID = checkDimName(fileID, (size_t) dimlen, dimname);
   if (dimID == CDI_UNDEFID) cdf_def_dim(fileID, dimname, (size_t) dimlen, &dimID);
 
-  int dataType = CDI_UNDEFID;
-  cdiInqKeyInt(gridID, CDI_GLOBAL, CDI_KEY_DATATYPE, &dataType);
-  nc_type xtype = NC_INT64;
-  if (dataType == CDI_DATATYPE_INT32) xtype = NC_INT;
-
   static const char axisname[] = "cell_index";
   static const char stdname[] = "healpix_index";
   static const char units[] = "1";
@@ -1875,7 +1883,6 @@ cdf_def_grid_indices(stream_t *streamptr, int gridID, int gridIndex)
   CdfGrid *cdfGridVec = streamptr->cdfInfo.cdfGridVec;
   cdfGridVec[gridIndex].gridID = gridID;
   cdfGridVec[gridIndex].ncIdVec[CDF_VARID_I] = ncivarid;
-#endif
   struct cdfPostDefActionList *delayed = NULL;
   return delayed;
 }
@@ -1942,10 +1949,8 @@ cdfDefCharacter(stream_t *streamptr, int gridID, int gridIndex, int cdiAxisID, i
     int gridtype0 = gridInqType(gridID0);
     if (gridtype0 == GRID_CHARXY)
     {
-      if (gridInqXIsc(gridID0) == strlen && gridInqXsize(gridID0) == dimlen)
-        return;
-      else if (gridInqYIsc(gridID0) == strlen && gridInqYsize(gridID0) == dimlen)
-        return;
+      if (gridInqXIsc(gridID0) == strlen && gridInqXsize(gridID0) == dimlen) { return; }
+      else if (gridInqYIsc(gridID0) == strlen && gridInqYsize(gridID0) == dimlen) { return; }
     }
   }
 
@@ -2201,8 +2206,11 @@ cdf_define_grid(stream_t *streamptr, int gridID, int gridIndex)
     if (gridSize == gridInqIndices(gridID, NULL))
     {
       struct cdfPostDefActionList *idelayed = cdf_def_grid_indices(streamptr, gridID, gridIndex);
-      delayed = cdfPostDefActionConcat(delayed, idelayed);
-      Free(idelayed);
+      if (idelayed)
+      {
+        delayed = cdfPostDefActionConcat(delayed, idelayed);
+        Free(idelayed);
+      }
     }
   }
   else if (gridType == GRID_GENERIC)
