@@ -1,30 +1,44 @@
-#if defined (HAVE_CONFIG_H)
-#  include "config.h"
+/* DO NOT REMOVE the config.h include file under any circumstances,
+ * it's very much needed on some platforms */
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
 #endif
+/* DO NOT REMOVE the above config.h include file under any
+ * circumstances as long as it's the autoconf configuration header
+ * used to build this package. When it's missing on some platforms,
+ * some poor person has to do long, tedious debugging sessions, where
+ * struct offsets almost imperceptibly change from one file to the
+ * next to find out what happened */
 
 #include <inttypes.h>
 #include <stdio.h>
 
 #include "swap.h"
 
-void swap4byte(void *ptr, size_t size)
+void
+swap4byte(void *ptr, size_t size)
 {
-  int32_t *ptrtmp = (int32_t *)ptr;
+  int32_t *ptrtmp = (int32_t *) ptr;
 
+  // clang-format off
   for (size_t i = 0; i < size; ++i)
     ptrtmp[i] = (((ptrtmp[i] >> 24) & 0x00ff) | ((ptrtmp[i] & 0x00ff) << 24) |
                  ((ptrtmp[i] >>  8) & 0xff00) | ((ptrtmp[i] & 0xff00) <<  8));
+  // clang-format on
 }
 
-void swap8byte(void *ptr, size_t size)
+void
+swap8byte(void *ptr, size_t size)
 {
-  int64_t *ptrtmp = (int64_t *)ptr;
+  int64_t *ptrtmp = (int64_t *) ptr;
 
+  // clang-format off
   for (size_t i = 0; i < size; ++i)
     ptrtmp[i] = (((ptrtmp[i] >> 56) & 0x000000ff) | ((ptrtmp[i] & 0x000000ff) << 56) |
                  ((ptrtmp[i] >> 40) & 0x0000ff00) | ((ptrtmp[i] & 0x0000ff00) << 40) |
                  ((ptrtmp[i] >> 24) & 0x00ff0000) | ((ptrtmp[i] & 0x00ff0000) << 24) |
                  ((ptrtmp[i] >>  8) & 0xff000000) | ((ptrtmp[i] & 0xff000000) <<  8));
+  // clang-format on
 }
 /*
  * Local Variables:
