@@ -11,6 +11,7 @@
 #include <cstdarg>
 
 #include "process_int.h"
+#include "cdo_output.h"
 #include "transform.h"
 #include "workerthread.h"
 #include "varray.h"
@@ -220,14 +221,14 @@ void after_EchamDependencies(struct Variable *vars, int ncodes, int type, int so
 
 void after_legini_setup(AfterControl &globs, struct Variable *vars);
 
-static WorkerThread *afterReadTask = nullptr;
+static WorkerThread *afterWorkerThread = nullptr;
 static bool afterReadAsync = true;
 
 template <typename... Args>
 void
-afterAbort(const std::string &format, Args const &...args)
+afterAbort(std::string const &format, Args const &...args)
 {
-  if (afterReadAsync && afterReadTask) afterReadTask->wait();
+  if (afterReadAsync && afterWorkerThread) afterWorkerThread->wait();
   cdo_abort(format, args...);
 }
 
