@@ -49,7 +49,7 @@ public:
 
   virtual size_t getNvals() = 0;
 
-  int get_id();
+  virtual int get_id() = 0;
   int getTsID();
 
   int m_cdoStreamID = -1;  // aka the id of the pstream
