@@ -1,6 +1,7 @@
 #include <cdi.h>
 
 #include <cstdlib>
+#include <cmath>
 #include <vector>
 
 // #include "cdi_int.h"
@@ -22,7 +23,7 @@ const char *
 filetype_to_cstr(int filetype)
 {
   switch (filetype)
-    {
+  {
       // clang-format off
     case CDI_FILETYPE_GRB:    return "GRIB";
     case CDI_FILETYPE_GRB2:   return "GRIB2";
@@ -37,13 +38,13 @@ filetype_to_cstr(int filetype)
     case CDI_FILETYPE_IEG:    return "IEG";
     default:                  return "";
       // clang-format on
-    }
+  }
 }
 
 const char *
 datatype_to_cstr(int datatype)
 {
-  static char cstr[20] = { 0 };
+  static char cstr[20]{};
   if (datatype > 0 && datatype <= 32) std::snprintf(cstr, sizeof(cstr), "P%d", datatype);
 
   // clang-format off
@@ -64,28 +65,28 @@ datatype_to_cstr(int datatype)
 }
 
 int
-str_to_datatype(const std::string &datatypeStr)
+str_to_datatype(std::string const &datatypeStr)
 {
   if (datatypeStr.size() > 1)
-    {
-      auto ilen = atoi(datatypeStr.c_str() + 1);
-      // clang-format off
-      if      (datatypeStr == "P0")     return CDI_DATATYPE_PACK;
-      else if (datatypeStr[0] == 'P' && ilen > 0 && ilen <= 32) return ilen;
-      else if (datatypeStr == "C32")    return CDI_DATATYPE_CPX32;
-      else if (datatypeStr == "C64")    return CDI_DATATYPE_CPX64;
-      else if (datatypeStr == "F32")    return CDI_DATATYPE_FLT32;
-      else if (datatypeStr == "F64")    return CDI_DATATYPE_FLT64;
-      else if (datatypeStr == "I8")     return CDI_DATATYPE_INT8;
-      else if (datatypeStr == "I16")    return CDI_DATATYPE_INT16;
-      else if (datatypeStr == "I32")    return CDI_DATATYPE_INT32;
-      else if (datatypeStr == "U8")     return CDI_DATATYPE_UINT8;
-      else if (datatypeStr == "U16")    return CDI_DATATYPE_UINT16;
-      else if (datatypeStr == "U32")    return CDI_DATATYPE_UINT32;
-      else if (datatypeStr == "real")   return CDI_DATATYPE_FLT32;
-      else if (datatypeStr == "double") return CDI_DATATYPE_FLT64;
-      // clang-format on
-    }
+  {
+    auto ilen = atoi(datatypeStr.c_str() + 1);
+    // clang-format off
+    if      (datatypeStr == "P0")     return CDI_DATATYPE_PACK;
+    else if (datatypeStr[0] == 'P' && ilen > 0 && ilen <= 32) return ilen;
+    else if (datatypeStr == "C32")    return CDI_DATATYPE_CPX32;
+    else if (datatypeStr == "C64")    return CDI_DATATYPE_CPX64;
+    else if (datatypeStr == "F32")    return CDI_DATATYPE_FLT32;
+    else if (datatypeStr == "F64")    return CDI_DATATYPE_FLT64;
+    else if (datatypeStr == "I8")     return CDI_DATATYPE_INT8;
+    else if (datatypeStr == "I16")    return CDI_DATATYPE_INT16;
+    else if (datatypeStr == "I32")    return CDI_DATATYPE_INT32;
+    else if (datatypeStr == "U8")     return CDI_DATATYPE_UINT8;
+    else if (datatypeStr == "U16")    return CDI_DATATYPE_UINT16;
+    else if (datatypeStr == "U32")    return CDI_DATATYPE_UINT32;
+    else if (datatypeStr == "real")   return CDI_DATATYPE_FLT32;
+    else if (datatypeStr == "double") return CDI_DATATYPE_FLT64;
+    // clang-format on
+  }
 
   return -1;
 }
@@ -148,11 +149,11 @@ cdo_vlist_gridsizemax(int vlistID)
 
   auto numGrids = vlistNumGrids(vlistID);
   for (int index = 0; index < numGrids; index++)
-    {
-      auto gridID = vlistGrid(vlistID, index);
-      auto gridsize = gridInqSize(gridID);
-      if (gridsize > gridsizemax) gridsizemax = gridsize;
-    }
+  {
+    auto gridID = vlistGrid(vlistID, index);
+    auto gridsize = gridInqSize(gridID);
+    if (gridsize > gridsizemax) gridsizemax = gridsize;
+  }
 
   return gridsizemax;
 }
@@ -161,7 +162,7 @@ namespace cdo
 {
 
 int
-inq_att_int(int cdiID, int varID, const std::string &attname)
+inq_att_int(int cdiID, int varID, std::string const &attname)
 {
   int attint = -1;
   cdiInqAttInt(cdiID, varID, attname.c_str(), 1, &attint);
@@ -169,24 +170,32 @@ inq_att_int(int cdiID, int varID, const std::string &attname)
 }
 
 std::string
-inq_att_string(int cdiID, int varID, const std::string &attname)
+inq_att_string(int cdiID, int varID, std::string const &attname)
 {
   int attlen = cdiInqAttLen(cdiID, varID, attname.c_str());
   std::vector<char> atttxt(1, 0);
   if (attlen > 0)
-    {
-      atttxt.resize(attlen + 1);
-      cdiInqAttTxt(cdiID, varID, attname.c_str(), attlen, atttxt.data());
-      atttxt[attlen] = 0;
-    }
+  {
+    atttxt.resize(attlen + 1);
+    cdiInqAttTxt(cdiID, varID, attname.c_str(), attlen, atttxt.data());
+    atttxt[attlen] = 0;
+  }
 
   return std::string(atttxt.data());
 }
 
+int
+inq_key_int(int cdiID, int varID, int key)
+{
+  int intValue{ 0 };
+  cdiInqKeyInt(cdiID, varID, key, &intValue);
+  return intValue;
+}
+
 std::string
 inq_key_string(int cdiID, int varID, int key)
 {
-  char cstr[CDI_MAX_NAME] = { 0 };
+  char cstr[CDI_MAX_NAME]{};
   int length = CDI_MAX_NAME;
   cdiInqKeyString(cdiID, varID, key, cstr, &length);
 
@@ -196,7 +205,7 @@ inq_key_string(int cdiID, int varID, int key)
 std::string
 inq_var_name(int vlistID, int varID)
 {
-  char cstr[CDI_MAX_NAME] = { 0 };
+  char cstr[CDI_MAX_NAME]{};
   vlistInqVarName(vlistID, varID, cstr);
   return std::string(cstr);
 }
@@ -204,7 +213,7 @@ inq_var_name(int vlistID, int varID)
 std::string
 inq_var_longname(int vlistID, int varID)
 {
-  char cstr[CDI_MAX_NAME] = { 0 };
+  char cstr[CDI_MAX_NAME]{};
   vlistInqVarLongname(vlistID, varID, cstr);
   return std::string(cstr);
 }
@@ -212,7 +221,7 @@ inq_var_longname(int vlistID, int varID)
 std::string
 inq_var_units(int vlistID, int varID)
 {
-  char cstr[CDI_MAX_NAME] = { 0 };
+  char cstr[CDI_MAX_NAME]{};
   vlistInqVarUnits(vlistID, varID, cstr);
   return std::string(cstr);
 }
@@ -220,18 +229,24 @@ inq_var_units(int vlistID, int varID)
 HpParams
 get_healpix_params(int gridID)
 {
+  auto gridType = gridInqType(gridID);
   auto projection = "healpix";
+  auto refinementLevel = cdo::inq_att_int(gridID, CDI_GLOBAL, "refinement_level");
   auto nside = cdo::inq_att_int(gridID, CDI_GLOBAL, "healpix_nside");
-  auto order = cdo::inq_att_string(gridID, CDI_GLOBAL, "healpix_order");
-  if (nside == -1 || order.empty())
-    {
-      if (order.empty()) cdo_warning("%s mapping parameter %s missing!", projection, "healpix_order");
-      if (nside == -1) cdo_warning("%s mapping parameter %s missing!", projection, "healpix_nside");
-      cdo_abort("%s mapping parameter missing!", "healpix");
-    }
-  if (nside < 1) cdo_abort("%s mapping parameter %s < 1!", projection, "healpix_nside");
+  auto paramName = (gridType == GRID_HEALPIX) ? "refinement_level" : "healpix_nside";
+  if (refinementLevel == -1 && nside == -1) { cdo_abort("%s mapping parameter %s missing!", projection, paramName); }
+
+  if (refinementLevel == -1) refinementLevel = std::log2(nside);
+  if (nside == -1) nside = std::lround(std::pow(2.0, refinementLevel));
+
+  auto indexingSchemeName = (gridType == GRID_HEALPIX) ? "indexing_scheme" : "healpix_order";
+  auto order = cdo::inq_att_string(gridID, CDI_GLOBAL, indexingSchemeName);
+  if (order.empty()) { cdo_abort("%s mapping parameter %s missing!", projection, indexingSchemeName); }
+
+  if (nside < 1) cdo_abort("%s mapping parameter %s < 1!", projection, paramName);
+
   auto hpOrder = hp_get_order(order);
-  if (hpOrder == HpOrder::Undef) cdo_abort("%s mapping parameter healpix_order=%s unsupported!", projection, order);
+  if (hpOrder == HpOrder::Undef) cdo_abort("%s mapping parameter %s=%s unsupported!", projection, indexingSchemeName, order);
 
   return HpParams{ nside, hpOrder };
 }
@@ -247,39 +262,35 @@ get_chunkspec_string(int vlistID, int varID)
   int chunkSize;
   int numDims = 0;
   for (auto [key, dim] : chunkList)
+  {
+    if (cdiInqKeyInt(vlistID, varID, key, &chunkSize) == 0)
     {
-      if (cdiInqKeyInt(vlistID, varID, key, &chunkSize) == 0)
-        {
-          if (numDims++) chunkSpecString += ",";
-          chunkSpecString += dim;
-          chunkSpecString += "=" + std::to_string(chunkSize);
-        }
+      if (numDims++) chunkSpecString += ",";
+      chunkSpecString += dim;
+      chunkSpecString += "=" + std::to_string(chunkSize);
     }
+  }
 
   return chunkSpecString;
 }
-
+/*
 void
 delete_chunks_dimT(int vlistID)
 {
   constexpr int dimT{ 0 };
-  constexpr int chunkKeys[4] = { CDI_KEY_CHUNKSIZE_DIMT, CDI_KEY_CHUNKSIZE_DIMZ, CDI_KEY_CHUNKSIZE_DIMY, CDI_KEY_CHUNKSIZE_DIMX };
-  int numVars = vlistNvars(vlistID);
+  constexpr int chunkKeys[] = { CDI_KEY_CHUNKSIZE_DIMT, CDI_KEY_CHUNKSIZE_DIMZ, CDI_KEY_CHUNKSIZE_DIMY, CDI_KEY_CHUNKSIZE_DIMX };
+  auto numVars = vlistNvars(vlistID);
   for (int varID = 0; varID < numVars; ++varID)
+  {
+    if (cdo::inq_key_int(vlistID, varID, chunkKeys[dimT]) != 0)
     {
-      int chunkSizeDimT = 0;
-      cdiInqKeyInt(vlistID, varID, chunkKeys[dimT], &chunkSizeDimT);
-      if (chunkSizeDimT != 0)
-        {
-          cdiDeleteKey(vlistID, varID, chunkKeys[dimT]);
-          for (int i = 1; i < 4; ++i)
-            {
-              int chunkSize = 0;
-              cdiInqKeyInt(vlistID, varID, chunkKeys[i], &chunkSize);
-              if (chunkSize != 0) cdiDeleteKey(vlistID, varID, chunkKeys[i]);
-            }
-        }
+      cdiDeleteKey(vlistID, varID, chunkKeys[dimT]);
+      for (int i = 1; i < 4; ++i)
+      {
+        if (cdo::inq_key_int(vlistID, varID, chunkKeys[i]) != 0) cdiDeleteKey(vlistID, varID, chunkKeys[i]);
+      }
     }
+  }
 }
-
+*/
 }  // namespace cdo
