@@ -7,14 +7,13 @@
 
 namespace cdo
 {
-
 // convert a CDI filetype to cstring
 const char *filetype_to_cstr(int filetype);
 
 // convert a CDI datatype to cstring
 const char *datatype_to_cstr(int datatype);
 
-int str_to_datatype(const std::string &datatypeStr);
+int str_to_datatype(std::string const &datatypeStr);
 
 const char *get_steptype_name(int tsteptype);
 
@@ -35,8 +34,10 @@ size_t cdo_vlist_gridsizemax(int vlistID);
 namespace cdo
 {
 
-int inq_att_int(int cdiID, int varID, const std::string &attname);
-std::string inq_att_string(int cdiID, int varID, const std::string &attname);
+int inq_att_int(int cdiID, int varID, std::string const &attname);
+std::string inq_att_string(int cdiID, int varID, std::string const &attname);
+
+int inq_key_int(int cdiID, int varID, int key);
 std::string inq_key_string(int cdiID, int varID, int key);
 
 std::string inq_var_name(int vlistID, int varID);
@@ -46,7 +47,7 @@ std::string inq_var_units(int vlistID, int varID);
 HpParams get_healpix_params(int gridID);
 
 std::string get_chunkspec_string(int vlistID, int varID);
-void delete_chunks_dimT(int vlistID);
+// void delete_chunks_dimT(int vlistID);
 
 }  // namespace cdo
 
