@@ -10,13 +10,13 @@ struct CmorVar
   bool convert = false;
   bool remove = false;
   // missing value
-  bool changemissval = false;
+  bool changeMissval = false;
   double missvalOld = 0.0;
   //
-  bool lfactor = false;
+  bool applyFactor = false;
   double factor = 0.0;
   //
-  bool checkvalid = false;
+  bool checkValid = false;
   double valid_min = 0.0;
   double valid_max = 0.0;
   //
@@ -26,8 +26,8 @@ struct CmorVar
   bool check_max_mean_abs = false;
   double ok_max_mean_abs = 0.0;
   // units
-  bool changeunits = false;
-  char units_old[CDI_MAX_NAME] = { 0 };
+  bool changeUnits = false;
+  char unitsOld[CDI_MAX_NAME] = { 0 };
   char units[CDI_MAX_NAME] = { 0 };
   // varname
   std::string name;
@@ -36,10 +36,12 @@ struct CmorVar
 
   double amean = 0;
   long nvals = 0, n_lower_min = 0, n_greater_max = 0;
+
+  std::string filterSpec;
 };
 
-void cmor_check_init(int nvars, std::vector<CmorVar> &vars);
-void cmor_check_eval(int vlistID, int nvars, const std::vector<CmorVar> &vars);
+void cmor_check_init(std::vector<CmorVar> &cmorVars);
+void cmor_check_eval(int vlistID, std::vector<CmorVar> const &cmorVars);
 void cmor_check_prep(CmorVar &var, long gridsize, double missval, const double *const array);
 
 #endif
