@@ -1,4 +1,5 @@
 #include <cstddef>
+// #include <random>
 
 #include "cdo_omp.h"
 #include "cdo_data.h"
@@ -44,54 +45,58 @@ const PackedData maskData(maskScale, maskOffset, mask, sizeof(mask) / sizeof(uns
 Varray<float>
 unpack_data(const PackedData &packedData)
 {
-  auto datasize = packedData.size;
-  Varray<float> data(datasize);
-  for (size_t i = 0; i < datasize; ++i) data[i] = packedData.pdata[i] / packedData.scale - packedData.offset;
+  auto n = packedData.size;
+  Varray<float> data(n);
+  for (size_t i = 0; i < n; ++i) data[i] = packedData.pdata[i] / packedData.scale - packedData.offset;
   return data;
 }
 
 void
 fill_random(Varray<float> &varray)
 {
+  // std::random_device rd;
+  // std::mt19937 gen(rd());
+  // std::uniform_real_distribution<> dis(0.0, 1.0);
+  // for (auto &v : varray) v = dis(gen);
   for (auto &v : varray) v = ((double) std::rand()) / ((double) RAND_MAX);
 }
 
 void
-fill_sincos(Varray<float> &varray, const Varray<double> &xvals, const Varray<double> &yvals)
+fill_sincos(Varray<float> &varray, Varray<double> const &xvals, Varray<double> const &yvals)
 {
-  auto len = varray.size();
+  auto n = varray.size();
 #ifdef HAVE_OPENMP4
-#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static)
+#pragma omp parallel for simd if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i) { varray[i] = std::cos(1.0 * xvals[i]) * std::sin(2.0 * yvals[i]); }
+  for (size_t i = 0; i < n; ++i) { varray[i] = std::cos(1.0 * xvals[i]) * std::sin(2.0 * yvals[i]); }
 }
 
 void
-fill_coshill(Varray<float> &varray, const Varray<double> &xvals, const Varray<double> &yvals)
+fill_coshill(Varray<float> &varray, Varray<double> const &xvals, Varray<double> const &yvals)
 {
-  auto len = varray.size();
+  auto n = varray.size();
 #ifdef HAVE_OPENMP4
-#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
+#pragma omp parallel for if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i) { varray[i] = 2.0 - std::cos(std::acos(std::cos(xvals[i]) * std::cos(yvals[i])) / 1.2); }
+  for (size_t i = 0; i < n; ++i) { varray[i] = 2.0 - std::cos(std::acos(std::cos(xvals[i]) * std::cos(yvals[i])) / 1.2); }
 }
 
 void
-fill_testfield(Varray<float> &varray, const Varray<double> &xvals, const Varray<double> &yvals)
+fill_testfield(Varray<float> &varray, Varray<double> const &xvals, Varray<double> const &yvals)
 {
-  auto len = varray.size();
+  auto n = varray.size();
 #ifdef HAVE_OPENMP4
-#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static)
+#pragma omp parallel for simd if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i)
-    {
-      double xyz[3];
-      gcLLtoXYZ(xvals[i], yvals[i], xyz);
-      auto x = xyz[0];
-      auto y = xyz[1];
-      auto z = xyz[2];
-      varray[i] = 1.0 + std::pow(x, 8.0) + std::exp(2.0 * y * y * y) + std::exp(2.0 * x * x) + 10.0 * x * y * z;
-    }
+  for (size_t i = 0; i < n; ++i)
+  {
+    double xyz[3];
+    gcLLtoXYZ(xvals[i], yvals[i], xyz);
+    auto x = xyz[0];
+    auto y = xyz[1];
+    auto z = xyz[2];
+    varray[i] = 1.0 + std::pow(x, 8.0) + std::exp(2.0 * y * y * y) + std::exp(2.0 * x * x) + 10.0 * x * y * z;
+  }
 }
 
 // Some Constants for creating temperatur and pressure for the standard atmosphere
