@@ -6,7 +6,7 @@
 
 struct CdoException : std::logic_error
 {
-  CdoException(const std::string &p_msg, const std::string &p_file, const std::string &p_line)
+  CdoException(std::string const &p_msg, std::string const &p_file, std::string const &p_line)
       : std::logic_error(p_msg), file(p_file), line(p_line)
   {
   }
