@@ -5,7 +5,6 @@
 
 */
 
-#include "cdi.h"
 #include "cdo_fill.h"
 #include "cdo_varlist.h"
 
@@ -14,7 +13,7 @@ cdo_fill_ts(int p_vlistID, Varray2D<double> &p_varData)
 {
   VarList varList(p_vlistID);
   p_varData.resize(varList.numVars());
-  for (const auto &var : varList.vars) { p_varData[var.ID].resize(var.nlevels * var.gridsize); }
+  for (auto const &var : varList.vars) { p_varData[var.ID].resize(var.nlevels * var.gridsize); }
 }
 
 void
@@ -23,7 +22,7 @@ cdo_fill_ts(int p_vlistID, Varray2D<double> &p_varData, Varray2D<size_t> &p_varN
   VarList varList(p_vlistID);
   p_varData.resize(varList.numVars());
   p_varNmiss.resize(varList.numVars());
-  for (const auto &var : varList.vars)
+  for (auto const &var : varList.vars)
     {
       p_varData[var.ID].resize(var.nlevels * var.gridsize);
       p_varNmiss[var.ID].resize(var.nlevels);
