@@ -26,9 +26,9 @@ struct CdoMagicsMapper
   const char *magics_name = nullptr;
   const char *magics_type = nullptr;
   // Function to Update the Corresponding Magics parameters
-  int (*Set_magics_param)(const char *user_name, const char *param_value);
+  int (*Set_magics_param)(const char *user_name, const char *param_value){};
   // Function to Reset the Corresponding Magics parameters
-  int (*Reset_magics_param)(const char *user_name);
+  int (*Reset_magics_param)(const char *user_name){};
 };
 
 CdoMagicsMapper mapper[] =
@@ -119,26 +119,26 @@ get_magics_parameter_info(const char *user_name, char *param_value)
   int ret_flag = 0;
 
   if (once)
-    {
-      std::qsort(mapper, PARAM_COUNT, sizeof(CdoMagicsMapper), Compare);
-      once = 0;
-    }
+  {
+    std::qsort(mapper, PARAM_COUNT, sizeof(CdoMagicsMapper), Compare);
+    once = 0;
+  }
 
   CdoMagicsMapper target;
   target.cdo_name = (char *) user_name;
   CdoMagicsMapper *result = (CdoMagicsMapper *) bsearch(&target, mapper, PARAM_COUNT, sizeof(CdoMagicsMapper), Compare);
   if (result)
-    {
-      result->Set_magics_param(result->cdo_name, param_value);
+  {
+    result->Set_magics_param(result->cdo_name, param_value);
 
-      // magics_name = result->magics_name;
-      // magics_type = result->magics_type;
-    }
+    // magics_name = result->magics_name;
+    // magics_type = result->magics_type;
+  }
   else
-    {
-      // Call the Reset functions of all the features to Reset the magics params to default in the calling function
-      ret_flag = 1;
-    }
+  {
+    // Call the Reset functions of all the features to Reset the magics params to default in the calling function
+    ret_flag = 1;
+  }
 
   return ret_flag;
 }
