@@ -27,7 +27,7 @@ oper_t::oper_t(const char *_name) : name(_name), help(default_help) {}
 oper_t::oper_t(const char *_name, const CdoHelp &p_help) : name(_name), enter(nullptr), help(p_help) {}
 
 int
-CdoModule::get_id(const std::string &oper) const
+CdoModule::get_id(std::string const &oper) const
 {
   for (size_t i = 0; i < operators.size(); i++)
     {
@@ -84,7 +84,7 @@ CdoModule::get_pos_restriction() const
 }
 
 int
-CdoModule::is_alias(const std::string &subject) const
+CdoModule::is_alias(std::string const &subject) const
 {
   for (size_t i = 0; i < aliases.size(); i++)
     {
@@ -94,7 +94,7 @@ CdoModule::is_alias(const std::string &subject) const
 }
 
 std::vector<oper_t>::const_iterator
-CdoModule::find_operator(const std::string &p_operatorName) const
+CdoModule::find_operator(std::string const &p_operatorName) const
 {
   auto res
       = std::find_if(begin(operators), end(operators), [&p_operatorName](const oper_t &o) { return o.name == p_operatorName; });
@@ -102,7 +102,7 @@ CdoModule::find_operator(const std::string &p_operatorName) const
 }
 
 const CdoHelp &
-CdoModule::get_help(const std::string &p_operatorName) const
+CdoModule::get_help(std::string const &p_operatorName) const
 {
   auto oper_iter = find_operator(p_operatorName);
   if (oper_iter == operators.end()) cdo_abort("Help for %s in module %s not found", p_operatorName, name);
