@@ -10,11 +10,11 @@
 struct NodeAttachException : public CdoException
 {
   std::vector<std::string>::const_iterator iter;
-  NodeAttachException(std::shared_ptr<Node> p_node, const std::string &p_msg, const std::string &p_file = "?",
-                      const std::string &p_line = "?")
+  NodeAttachException(std::shared_ptr<Node> p_node, std::string const &p_msg, std::string const &p_file = "?",
+                      std::string const &p_line = "?")
       : CdoException(p_msg, p_file, p_line), iter(p_node->iter){};
-  NodeAttachException(std::vector<std::string>::const_iterator p_iter, const std::string &p_msg, const std::string &p_file = "?",
-                      const std::string &p_line = "?")
+  NodeAttachException(std::vector<std::string>::const_iterator p_iter, std::string const &p_msg, std::string const &p_file = "?",
+                      std::string const &p_line = "?")
       : CdoException(p_msg, p_file, p_line), iter(p_iter){};
 };
 
