@@ -63,7 +63,7 @@ extern bool Use_FFTW;
 extern bool VersionInfo;
 extern int CMOR_Mode;
 
-extern bool cdoDiag;
+extern bool CDO_diagnostic;
 
 extern MemType CDO_Memtype;
 
@@ -73,6 +73,7 @@ extern bool CDO_task;
 extern int CDO_Reduce_Dim;
 extern int CDO_Append_History;
 extern bool CDO_Reset_History;
+extern bool PrintFilename;
 
 extern unsigned Random_Seed;
 
@@ -85,10 +86,11 @@ extern int cdoChunkSizeDimX;
 extern bool cdoOverwriteMode;
 extern bool cdoParIO;
 extern bool cdoRegulargrid;
-size_t cdo_num_varnames();
+extern std::string cdoQueryParameter;
 extern std::vector<std::string> cdoVarnames;
+size_t cdo_num_varnames();
 
-extern bool REMAP_genweights;
+extern bool RemapGenerateWeights;
 
 }  // namespace Options
 
@@ -105,6 +107,6 @@ void set_compression(int fileID, int filetype);
 
 void cdo_set_search_radius(double searchRadius);
 double cdo_get_search_radius(void);
-void cdo_print_attributes(FILE *fp, int cdiID, int varID, int nblanks);
+void cdo_print_attributes(std::FILE *fp, int cdiID, int varID, int nblanks);
 
 #endif
