@@ -8,7 +8,7 @@ namespace cdo
 
 extern int netcdf_hdr_pad;
 
-int evaluate_except_options(const std::string &arg);
+int evaluate_except_options(std::string const &arg);
 int set_feenableexcept(int excepts);
 
 void set_cdi_options();
@@ -16,14 +16,14 @@ void set_external_proj_func();
 
 void signal_handler(int signo);
 
-void set_digits(const std::string &arg);
+void set_digits(std::string const &arg);
 void set_default_filetype(std::string filetypeString);
-void set_default_datatype(const std::string &datatypeString);
-void set_filterspec(const std::string &arg);
-void set_compression_type(const std::string &arg);
-void set_chunktype(const std::string &arg);
+void set_default_datatype(std::string const &datatypeString);
+void set_filterspec(std::string const &arg);
+void set_compression_type(std::string const &arg);
+void set_chunktype(std::string const &arg);
 
-void evaluate_color_options(const std::string &arg);
+void evaluate_color_options(std::string const &arg);
 
 void setup_openMP(int ompNumUserRequestedThreads);
 
