@@ -23,7 +23,7 @@ int vlist_get_first_gaussian_grid(int vlistID);
 int vlist_get_first_spectral_grid(int vlistID);
 int vlist_get_first_fourier_grid(int vlistID);
 
-void cdo_check_missval(double missval, const std::string &varname);
+void cdo_check_missval(double missval, std::string const &varname);
 
 void vlist_unpack(int vlistID);
 
