@@ -11,13 +11,13 @@
 #include "cellsearch_utils.h"
 #include "varray.h"
 
-void grid_boundbox_reg2d(size_t nx, size_t ny, const Varray<double> &cornerLonsReg2d, const Varray<double> &cornerLatsReg2d,
+void grid_boundbox_reg2d(size_t nx, size_t ny, Varray<double> const &cornerLonsReg2d, Varray<double> const &cornerLatsReg2d,
                          double *gridBoundBox);
 
 class CellsearchReg2d
 {
 public:
-  CellsearchReg2d(const Varray<double> &cornerLonsReg2d, const Varray<double> &cornerLatsReg2d, const CellsearchParams &params)
+  CellsearchReg2d(Varray<double> const &cornerLonsReg2d, Varray<double> const &cornerLatsReg2d, const CellsearchParams &params)
   {
     m_nx = params.dims[0];
     m_ny = params.dims[1];
@@ -28,7 +28,7 @@ public:
   size_t do_cellsearch(bool isReg2dCell, const GridCell &gridCell, Varray<size_t> &searchIndices);
 
   void
-  create(const Varray<double> &cornerLonsReg2d, const Varray<double> &cornerLatsReg2d)
+  create(Varray<double> const &cornerLonsReg2d, Varray<double> const &cornerLatsReg2d)
   {
     auto nxp1 = m_nx + 1;
     auto nyp1 = m_ny + 1;
