@@ -12,7 +12,7 @@
 
 extern "C"
 {
-#include "lib/yac/grid_cell.h"
+#include "lib/yac/src/grid_cell.h"
 }
 
 struct GridCell
