@@ -6,7 +6,6 @@
 */
 
 #include <vector>
-
 #include <cstring>
 
 static int gargc = 0;
@@ -18,7 +17,7 @@ static void
 initCommandLine(void)
 {
   size_t maxlen = 1;
-  for (int iarg = 0; iarg < gargc; iarg++) maxlen += strlen(gargv[iarg]) + 1;
+  for (int iarg = 0; iarg < gargc; iarg++) maxlen += std::strlen(gargv[iarg]) + 1;
 
   CDO_CommandLine.resize(maxlen);
 
