@@ -17,7 +17,7 @@ constexpr double C_EARTH_GRAV = 9.80665;
 #define C_RG (1.0 / PlanetGrav)
 
 constexpr double C_RCPV = 4.0 * C_RV;
-#define C_RETV (C_RV / PlanetRD - 1.)
+#define C_RETV (C_RV / PlanetRD - 1.0)
 constexpr double C_RCW = 4218.;        // specific water heat capacity ??
 constexpr double C_RCS = 2106.;        // specific ice heat capacity ??
 constexpr double C_RTT = 273.16;       // melting temperature of ice/snow
@@ -28,6 +28,10 @@ constexpr double C_RESTT = 611.14;
 
 constexpr double C_TIMES_RHOH2O = -333700000.0;
 
+constexpr double PlanetRDDefault = C_EARTH_RD;
+constexpr double PlanetRadiusDefault = C_EARTH_RADIUS;
+constexpr double PlanetGravDefault = C_EARTH_GRAV;
+
 extern double PlanetRD;
 extern double PlanetRadius;
 extern double PlanetGrav;
