@@ -8,6 +8,8 @@
 #define CPP_LIB_H
 
 #include <version>
+#include <ranges>
+#include <span>
 
 #if __cpp_lib_ranges >= 201911L
 #define HAVE_LIB_RANGES 1
