@@ -14,6 +14,8 @@
 #include <vector>
 #include <variant>
 
+#include "varray.h"
+
 extern int CDO_parser_errorno;
 
 enum CoordIndex
@@ -77,7 +79,7 @@ struct funNodeType
   int nops;                           // number of operands
   std::vector<struct nodeType *> op;  // operands
 
-  funNodeType(const std::string &fname, int _nops, va_list args) : name(fname), nops(_nops)
+  funNodeType(std::string const &fname, int _nops, va_list args) : name(fname), nops(_nops)
   {
     op.resize(nops);
     for (int i = 0; i < nops; i++) op[i] = va_arg(args, nodeType *);
@@ -150,7 +152,7 @@ struct nodeType
 
 struct CoordType
 {
-  std::vector<double> data;
+  Varray<double> data;
   std::string units;
   std::string longname;
   size_t size;
