@@ -18,11 +18,11 @@ enum struct FillMethod
   Backward
 };
 
-FillMethod string_to_fillmethod(const std::string &methodStr);
+FillMethod string_to_fillmethod(std::string const &methodStr);
 
-void fill_1d_nearest(int numValues, const Varray<double> &timeValues, Varray<double> &dataValues, double missval, int limit,
+void fill_1d_nearest(int numValues, Varray<double> const &timeValues, Varray<double> &dataValues, double missval, int limit,
                      int maxGaps);
-void fill_1d_linear(int numValues, const Varray<double> &timeValues, Varray<double> &dataValues, double missval, int limit,
+void fill_1d_linear(int numValues, Varray<double> const &timeValues, Varray<double> &dataValues, double missval, int limit,
                     int maxGaps);
 void fill_1d_forward(int numValues, Varray<double> &dataValues, double missval, int limit, int maxGaps);
 void fill_1d_backward(int numValues, Varray<double> &dataValues, double missval, int limit, int maxGaps);
