@@ -94,3 +94,11 @@ size_t getMemorySize(void)
 #endif
 	return 0L;			/* Unknown OS. */
 }
+
+#ifdef TEST
+#include <stdio.h>
+int main(void)
+{
+  printf("%zuGB\n", getMemorySize() / (1024 * 1024 * 1024));
+}
+#endif
