@@ -197,20 +197,20 @@ mod_huiliers_area(int num_corners, double *cell_corner_lon, double *cell_corner_
   lonlat_to_xyz(cell_corner_lon[1], cell_corner_lat[1], pnt2);
 
   for (int i = 2; i < num_corners; ++i)
+  {
+    // points that make up a side of cell
+    lonlat_to_xyz(cell_corner_lon[i], cell_corner_lat[i], pnt3);
+
+    // compute angle for pnt2
+    sum += mod_tri_area(pnt1, pnt2, pnt3);
+
+    if (i < (num_corners - 1))
     {
-      // points that make up a side of cell
-      lonlat_to_xyz(cell_corner_lon[i], cell_corner_lat[i], pnt3);
-
-      // compute angle for pnt2
-      sum += mod_tri_area(pnt1, pnt2, pnt3);
-
-      if (i < (num_corners - 1))
-        {
-          pnt2[0] = pnt3[0];
-          pnt2[1] = pnt3[1];
-          pnt2[2] = pnt3[2];
-        }
+      pnt2[0] = pnt3[0];
+      pnt2[1] = pnt3[1];
+      pnt2[2] = pnt3[2];
     }
+  }
 
   return sum;
 }
@@ -229,32 +229,32 @@ mod_huiliers_area2(int num_corners, double *cell_corner_lon, double *cell_corner
   lonlat_to_xyz(cell_corner_lon[0], cell_corner_lat[0], pnt2);
 
   for (int i = 1; i < num_corners; ++i)
-    {
-      if (is_equal(cell_corner_lon[i], cell_corner_lon[i - 1]) && is_equal(cell_corner_lat[i], cell_corner_lat[i - 1])) continue;
+  {
+    if (is_equal(cell_corner_lon[i], cell_corner_lon[i - 1]) && is_equal(cell_corner_lat[i], cell_corner_lat[i - 1])) continue;
 
-      // points that make up a side of cell
-      lonlat_to_xyz(cell_corner_lon[i], cell_corner_lat[i], pnt3);
+    // points that make up a side of cell
+    lonlat_to_xyz(cell_corner_lon[i], cell_corner_lat[i], pnt3);
 
-      // compute angle for pnt2
-      sum += mod_tri_area(pnt1, pnt2, pnt3);
+    // compute angle for pnt2
+    sum += mod_tri_area(pnt1, pnt2, pnt3);
 
-      pnt2[0] = pnt3[0];
-      pnt2[1] = pnt3[1];
-      pnt2[2] = pnt3[2];
-    }
+    pnt2[0] = pnt3[0];
+    pnt2[1] = pnt3[1];
+    pnt2[2] = pnt3[2];
+  }
 
   if (!(is_equal(cell_corner_lon[0], cell_corner_lon[num_corners - 1])
         && is_equal(cell_corner_lat[0], cell_corner_lat[num_corners - 1])))
-    {
-      lonlat_to_xyz(cell_corner_lon[0], cell_corner_lat[0], pnt3);
-      sum += mod_tri_area(pnt1, pnt2, pnt3);
-    }
+  {
+    lonlat_to_xyz(cell_corner_lon[0], cell_corner_lat[0], pnt3);
+    sum += mod_tri_area(pnt1, pnt2, pnt3);
+  }
 
   return sum;
 }
 
 static void
-getLonLatCorner(size_t nx, size_t idx, std::vector<double> const &grid_corner_lon, std::vector<double> const &grid_corner_lat,
+getLonLatCorner(size_t nx, size_t idx, Varray<double> const &grid_corner_lon, Varray<double> const &grid_corner_lat,
                 double (&lons)[4], double (&lats)[4])
 {
   auto j = idx / nx;
@@ -266,23 +266,23 @@ getLonLatCorner(size_t nx, size_t idx, std::vector<double> const &grid_corner_lo
   lons[3] = grid_corner_lon[2 * i];
 
   if (grid_corner_lat[2 * j + 1] > grid_corner_lat[2 * j])
-    {
-      lats[0] = grid_corner_lat[2 * j];
-      lats[1] = grid_corner_lat[2 * j];
-      lats[2] = grid_corner_lat[2 * j + 1];
-      lats[3] = grid_corner_lat[2 * j + 1];
-    }
+  {
+    lats[0] = grid_corner_lat[2 * j];
+    lats[1] = grid_corner_lat[2 * j];
+    lats[2] = grid_corner_lat[2 * j + 1];
+    lats[3] = grid_corner_lat[2 * j + 1];
+  }
   else
-    {
-      lats[0] = grid_corner_lat[2 * j + 1];
-      lats[1] = grid_corner_lat[2 * j + 1];
-      lats[2] = grid_corner_lat[2 * j];
-      lats[3] = grid_corner_lat[2 * j];
-    }
+  {
+    lats[0] = grid_corner_lat[2 * j + 1];
+    lats[1] = grid_corner_lat[2 * j + 1];
+    lats[2] = grid_corner_lat[2 * j];
+    lats[3] = grid_corner_lat[2 * j];
+  }
 }
 
 static int
-gen_gridcellarea_reg2d(int gridID, std::vector<double> &area, bool lweights)
+gen_gridcellarea_reg2d(int gridID, Varray<double> &area, bool lweights)
 {
   // lweights = true : area used only to calculate weights
 
@@ -295,61 +295,61 @@ gen_gridcellarea_reg2d(int gridID, std::vector<double> &area, bool lweights)
   if (!nlat) nlat = 1;
 
   if (!(gridHasCoordinates(gridID) || gridHasBounds(gridID) || (nlon == 1 && gridInqYvals(gridID, nullptr))))
-    {
-      cdo_warning("Computation of grid cell area weights failed, grid cell center and bounds coordinates missing!");
-      return 1;
-    }
+  {
+    cdo_warning("Computation of grid cell area weights failed, grid cell center and bounds coordinates missing!");
+    return 1;
+  }
 
-  std::vector<double> grid_corner_lon(nlon * 2), grid_corner_lat(nlat * 2);
+  Varray<double> grid_corner_lon(nlon * 2), grid_corner_lat(nlat * 2);
 
   if (gridInqXbounds(gridID, nullptr))
-    {
-      gridInqXbounds(gridID, grid_corner_lon.data());
-      unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
-    }
+  {
+    gridInqXbounds(gridID, grid_corner_lon.data());
+    unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
+  }
   else if (nlon == 1)
+  {
+    if (lweights)
     {
-      if (lweights)
-        {
-          grid_corner_lon[0] = 0;
-          grid_corner_lon[1] = .01;
-          unitstr = "radian";
-        }
-      else
-        return 1;
+      grid_corner_lon[0] = 0;
+      grid_corner_lon[1] = .01;
+      unitstr = "radian";
     }
+    else
+      return 1;
+  }
   else
-    {
-      std::vector<double> grid_center_lon(nlon);
-      gridInqXvals(gridID, grid_center_lon.data());
-      grid_gen_bounds(nlon, grid_center_lon, grid_corner_lon);
-      unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
-    }
+  {
+    Varray<double> grid_center_lon(nlon);
+    gridInqXvals(gridID, grid_center_lon.data());
+    grid_gen_bounds(nlon, grid_center_lon, grid_corner_lon);
+    unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
+  }
 
   if (gridInqYbounds(gridID, nullptr))
-    {
-      gridInqYbounds(gridID, grid_corner_lat.data());
-      unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
-    }
+  {
+    gridInqYbounds(gridID, grid_corner_lat.data());
+    unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
+  }
   else if (nlat == 1)
+  {
+    if (lweights)
     {
-      if (lweights)
-        {
-          grid_corner_lat[0] = 0;
-          grid_corner_lat[1] = .01;
-          unitstr = "radian";
-        }
-      else
-        return 1;
+      grid_corner_lat[0] = 0;
+      grid_corner_lat[1] = .01;
+      unitstr = "radian";
     }
+    else
+      return 1;
+  }
   else
-    {
-      std::vector<double> grid_center_lat(nlat);
-      gridInqYvals(gridID, grid_center_lat.data());
-      grid_gen_bounds(nlat, grid_center_lat, grid_corner_lat);
-      grid_check_lat_borders(nlat * 2, grid_corner_lat);
-      unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
-    }
+  {
+    Varray<double> grid_center_lat(nlat);
+    gridInqYvals(gridID, grid_center_lat.data());
+    grid_gen_bounds(nlat, grid_center_lat, grid_corner_lat);
+    grid_check_lat_borders(nlat * 2, grid_corner_lat);
+    unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
+  }
 
   if (string_to_LonLatUnits(unitstr, "grid cell corner longitudes") == LonLatUnits::Deg) grid_to_radian(grid_corner_lon);
   if (string_to_LonLatUnits(unitstr, "grid cell corner latitudes") == LonLatUnits::Deg) grid_to_radian(grid_corner_lat);
@@ -363,28 +363,28 @@ gen_gridcellarea_reg2d(int gridID, std::vector<double> &area, bool lweights)
 #pragma omp parallel for if (gridsize > cdoMinLoopSize) default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && gridsize > progressMinSize) progress.update((double) atomicCount / gridsize);
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && gridsize > progressMinSize) progress.update((double) atomicCount / gridsize);
 
-      double lons[4], lats[4];
-      getLonLatCorner(nlon, i, grid_corner_lon, grid_corner_lat, lons, lats);
-      area[i] = mod_huiliers_area(nv, lons, lats);
-    }
+    double lons[4], lats[4];
+    getLonLatCorner(nlon, i, grid_corner_lon, grid_corner_lat, lons, lats);
+    area[i] = mod_huiliers_area(nv, lons, lats);
+  }
 
   return status;
 }
 
 int
-gridGenAreaReg2Dweights(int gridID, std::vector<double> &area)
+gridGenAreaReg2Dweights(int gridID, Varray<double> &area)
 {
   bool lweights = true;
   return gen_gridcellarea_reg2d(gridID, area, lweights);
 }
 
 static int
-gen_gridcellarea_unstruct(int gridID, std::vector<double> &area)
+gen_gridcellarea_unstruct(int gridID, Varray<double> &area)
 {
   int status = 0;
   auto lgriddestroy = false;
@@ -393,55 +393,55 @@ gen_gridcellarea_unstruct(int gridID, std::vector<double> &area)
   auto gridtype = gridInqType(gridID);
 
   if (gridtype != GRID_UNSTRUCTURED && gridtype != GRID_CURVILINEAR)
+  {
+    if (gridtype == GRID_GME || gridtype == GRID_GAUSSIAN_REDUCED)
     {
-      if (gridtype == GRID_GME || gridtype == GRID_GAUSSIAN_REDUCED)
-        {
-          lgriddestroy = true;
-          gridID = gridToUnstructured(gridID, NeedCorners::Yes);
-        }
-      else
-        {
-          lgriddestroy = true;
-          gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
-        }
+      lgriddestroy = true;
+      gridID = gridToUnstructured(gridID, NeedCorners::Yes);
     }
+    else
+    {
+      lgriddestroy = true;
+      gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
+    }
+  }
 
   if (gridtype == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID))
+  {
+    auto reference = dereferenceGrid(gridID);
+    if (reference.exists)
     {
-      auto reference = dereferenceGrid(gridID);
-      if (reference.exists)
-        {
-          if (!reference.isValid)
-            {
-              cdo_warning("Reference to source grid not found!");
-              return 1;
-            }
-          gridID = reference.gridID;
-          lgriddestroy = true;
-        }
+      if (!reference.isValid)
+      {
+        cdo_warning("Reference to source grid not found!");
+        return 1;
+      }
+      gridID = reference.gridID;
+      lgriddestroy = true;
     }
+  }
 
   gridtype = gridInqType(gridID);
 
   size_t nv = (gridtype == GRID_UNSTRUCTURED) ? gridInqNvertex(gridID) : 4;
 
   if (!gridHasCoordinates(gridID))
-    {
-      cdo_warning("Computation of grid cell area weights failed, grid cell center coordinates missing!");
-      return 1;
-    }
+  {
+    cdo_warning("Computation of grid cell area weights failed, grid cell center coordinates missing!");
+    return 1;
+  }
 
   if (nv == 0)
-    {
-      cdo_warning("Computation of grid cell area weights failed, grid cell corner coordinates missing!");
-      return 1;
-    }
+  {
+    cdo_warning("Computation of grid cell area weights failed, grid cell corner coordinates missing!");
+    return 1;
+  }
 
-  std::vector<double> grid_center_lon(gridsize), grid_center_lat(gridsize);
+  Varray<double> grid_center_lon(gridsize), grid_center_lat(gridsize);
   gridInqXvals(gridID, grid_center_lon.data());
   gridInqYvals(gridID, grid_center_lat.data());
 
-  std::vector<double> grid_corner_lon(nv * gridsize), grid_corner_lat(nv * gridsize);
+  Varray<double> grid_corner_lon(nv * gridsize), grid_corner_lat(nv * gridsize);
 
   if (!gridHasBounds(gridID)) return 1;
 
@@ -464,23 +464,22 @@ gen_gridcellarea_unstruct(int gridID, std::vector<double> &area)
 #pragma omp parallel for if (gridsize > cdoMinLoopSize) default(shared) schedule(static)
 #endif
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && gridsize > progressMinSize) progress.update((double) atomicCount / gridsize);
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && gridsize > progressMinSize) progress.update((double) atomicCount / gridsize);
 
-      if (nv <= 4)
-        area[i] = mod_huiliers_area(nv, &grid_corner_lon[i * nv], &grid_corner_lat[i * nv]);
-      else
-        area[i]
-            = mod_huiliers_area2(nv, &grid_corner_lon[i * nv], &grid_corner_lat[i * nv], grid_center_lon[i], grid_center_lat[i]);
-    }
+    if (nv <= 4)
+      area[i] = mod_huiliers_area(nv, &grid_corner_lon[i * nv], &grid_corner_lat[i * nv]);
+    else
+      area[i] = mod_huiliers_area2(nv, &grid_corner_lon[i * nv], &grid_corner_lat[i * nv], grid_center_lon[i], grid_center_lat[i]);
+  }
 
   return status;
 }
 
 int
-gen_gridcellarea_healpix(int gridID, std::vector<double> &area)
+gen_gridcellarea_healpix(int gridID, Varray<double> &area)
 {
   auto gridsize = gridInqSize(gridID);
   auto cellarea = 4.0 * M_PI / gridsize;
@@ -489,7 +488,7 @@ gen_gridcellarea_healpix(int gridID, std::vector<double> &area)
 }
 
 int
-gridGenArea(int gridID, std::vector<double> &area)
+gridGenArea(int gridID, Varray<double> &area)
 {
   int status = 0;
 
@@ -497,16 +496,16 @@ gridGenArea(int gridID, std::vector<double> &area)
   auto gridtype = gridInqType(gridID);
 
   if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN)
-    {
-      bool lweights = false;
-      status = gen_gridcellarea_reg2d(gridID, area, lweights);
-    }
+  {
+    bool lweights = false;
+    status = gen_gridcellarea_reg2d(gridID, area, lweights);
+  }
   else if (is_healpix_grid(gridID)) { status = gen_gridcellarea_healpix(gridID, area); }
   else if (gridProjIsSupported(gridID) || gridtype == GRID_GME || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED
            || gridtype == GRID_GAUSSIAN_REDUCED)
-    {
-      status = gen_gridcellarea_unstruct(gridID, area);
-    }
+  {
+    status = gen_gridcellarea_unstruct(gridID, area);
+  }
   else { cdo_abort("Internal error! Unsupported gridtype: %s", gridNamePtr(gridtype)); }
 
   if (gridVerbose) cdo_print("Total area = %g steradians", varray_sum(gridsize, area));
