@@ -11,10 +11,10 @@
 
 class Field;
 
-void interpolate(const Field &field1, Field &field2);
-void intgrid_bil(const Field &field1, Field &field2);
-void intgrid_1nn(const Field &field1, Field &field2);
-void intgrid_knn(const KnnParams &knnParams, const Field &field1, Field &field2);
+void interpolate(Field const &field1, Field &field2);
+void intgrid_bil(Field const &field1, Field &field2);
+void intgrid_1nn(Field const &field1, Field &field2);
+void intgrid_knn(KnnParams const &knnParams, Field const &field1, Field &field2);
 
 constexpr double
 intlin(double x, double y1, double x1, double y2, double x2)
