@@ -30,15 +30,18 @@ enum struct WeightingMethod
 };
 
 std::string weightingMethod_to_string(WeightingMethod method);
-WeightingMethod string_to_weightingMethod(const std::string &methodStr);
+WeightingMethod string_to_weightingMethod(std::string const &methodStr);
+
+constexpr double CDO_INTERP_NNN_GAUSS_SCALE_DEFAULT = 0.1;
+constexpr double CDO_INTERP_NNN_RBF_SCALE_DEFAULT = 14.87973;
 
 struct KnnParams
 {
   size_t k{ 1 };
   size_t kMin{ 0 };
   double maxSearchDistance{ 0.0 };
-  double gaussScale{ 1.0 };
-  double rbfScale{ 1.0 };
+  double gaussScale{ CDO_INTERP_NNN_GAUSS_SCALE_DEFAULT };
+  double rbfScale{ CDO_INTERP_NNN_RBF_SCALE_DEFAULT };
   WeightingMethod weighted{ WeightingMethod::distanceWeighted };
   bool extrapolate{ false };
   // linear
@@ -53,14 +56,14 @@ private:
   size_t m_kMin{ 0 };
   size_t m_maxPoints{ 0 };
   size_t m_maxNeighbors{ 0 };
-  double m_gaussScale{ 1.0 };
-  double m_rbfScale{ 1.0 };
+  double m_gaussScale{ CDO_INTERP_NNN_GAUSS_SCALE_DEFAULT };
+  double m_rbfScale{ CDO_INTERP_NNN_RBF_SCALE_DEFAULT };
   // linear
   double m_searchRadius{ 0.0 };
   double m_weight0{ 1.0 };
   double m_weightR{ 1.0 };
 
-  void apply_mask(const Vmask &gridMask);
+  void apply_mask(Vmask const &gridMask);
 
   size_t compute_weights_avg();
   size_t compute_weights_dist();
@@ -70,12 +73,12 @@ private:
 
 public:
   WeightingMethod m_weighted{ WeightingMethod::distanceWeighted };
-  size_t m_numNeighbors = 0;
-  std::vector<size_t> m_indices;  // source indices at nearest neighbors
-  std::vector<double> m_dist;     // angular distance four nearest neighbors
-  std::vector<size_t> m_tmpIndices;
-  std::vector<double> m_tmpDist;
-  std::unique_ptr<double[][3]> m_srcCoords;
+  size_t m_numNeighbors{};
+  std::vector<size_t> m_indices{};  // source indices at nearest neighbors
+  std::vector<double> m_dist{};     // angular distance four nearest neighbors
+  std::vector<size_t> m_tmpIndices{};
+  std::vector<double> m_tmpDist{};
+  std::unique_ptr<double[][3]> m_srcCoords{};
   double m_tgtCoord[3];
   bool m_needCoords{ false };
 
@@ -90,11 +93,10 @@ public:
     if (m_needCoords) { m_srcCoords = std::make_unique<double[][3]>(m_maxPoints); }
   }
 
-  explicit KnnData(KnnParams knnParams)
+  explicit KnnData(KnnParams const &knnParams) : m_weighted(knnParams.weighted)
   {
     m_maxNeighbors = knnParams.k;
     m_kMin = knnParams.kMin;
-    m_weighted = knnParams.weighted;
     m_gaussScale = knnParams.gaussScale;
     m_rbfScale = knnParams.rbfScale;
     m_searchRadius = knnParams.searchRadius;
@@ -104,11 +106,10 @@ public:
     init();
   }
   explicit KnnData(size_t maxNeighbors) : m_maxNeighbors(maxNeighbors) { init(); }
-  explicit KnnData(KnnData &&other)
+  explicit KnnData(KnnData &&other) : m_weighted(other.m_weighted)
   {
     m_maxNeighbors = other.m_maxNeighbors;
     m_kMin = other.m_kMin;
-    m_weighted = other.m_weighted;
     m_gaussScale = other.m_gaussScale;
     m_rbfScale = other.m_rbfScale;
     m_searchRadius = other.m_searchRadius;
@@ -138,13 +139,13 @@ public:
   inline void
   init_indices(size_t numNeighbors)
   {
-    for (size_t i = 0; i < numNeighbors; ++i) m_indices[i] = SIZE_MAX;
+    for (size_t i = 0; i < numNeighbors; ++i) { m_indices[i] = SIZE_MAX; }
   }
 
   inline void
   init_dist(size_t numNeighbors)
   {
-    for (size_t i = 0; i < numNeighbors; ++i) m_dist[i] = DBL_MAX;
+    for (size_t i = 0; i < numNeighbors; ++i) { m_dist[i] = DBL_MAX; }
   }
 
   inline void
@@ -183,7 +184,7 @@ public:
   }
 
   size_t
-  compute_weights(const Vmask &gridMask)
+  compute_weights(Vmask const &gridMask)
   {
     // Compute weights if grid mask is false, eliminate those points
     apply_mask(gridMask);
@@ -192,10 +193,10 @@ public:
 
   template <typename T>
   double
-  array_weights_sum(const Varray<T> &array) const
+  array_weights_sum(Varray<T> const &array) const
   {
     double sum = 0.0;
-    for (size_t i = 0; i < m_numNeighbors; ++i) sum += array[m_indices[i]] * m_dist[i];
+    for (size_t i = 0; i < m_numNeighbors; ++i) { sum += array[m_indices[i]] * m_dist[i]; }
     return sum;
   }
 };
