@@ -93,7 +93,7 @@ gabswp2(void *r, gaint cnt)
   The GrADS system is case insensitive, and assumes lower case
   internally in most cases. Does not turn to lower case if in "'s
 */
-void
+static void
 lowcas(char *ch)
 {
   int i;
@@ -102,23 +102,14 @@ lowcas(char *ch)
   while (*ch != '\0' && *ch != '\n')
     {
       i = *ch;
-      if (*ch == '\"' && qflag == 0)
-        {
-          qflag = 1;
-        }
-      else if (*ch == '\"' && qflag == 1)
-        {
-          qflag = 0;
-        }
+      if (*ch == '\"' && qflag == 0) { qflag = 1; }
+      else if (*ch == '\"' && qflag == 1) { qflag = 0; }
       if (i > 64 && i < 91 && qflag == 0)
         {
           i += 32;
           *ch = i;
         }
-      else if (i == 95)
-        {
-          *ch = i;
-        }
+      else if (i == 95) { *ch = i; }
       ch++;
     }
 }
@@ -138,7 +129,7 @@ static gaint mnacul[13] = { 0, 0, 44640, 86400, 131040, 174240, 218880, 262080,
       Divisible by 100, it is not a leap year, unless...
       Divisible by 400, it is a leap year.                           */
 
-gaint
+static gaint
 qleap(gaint year)
 {
   gaint i, y;
@@ -166,7 +157,7 @@ qleap(gaint year)
 
 /* Add an offset to a time.  Output to dto.                          */
 
-void
+static void
 timadd(struct dt *dtim, struct dt *dto)
 {
   gaint i;
@@ -231,7 +222,7 @@ timadd(struct dt *dtim, struct dt *dto)
 /* Subtract an offset from a time.  Subtract minutes/hours/days
    first so that we will exactly reverse the operation of timadd     */
 
-void
+static void
 timsub(struct dt *dtim, struct dt *dto)
 {
   gaint s1, s2;
@@ -302,11 +293,11 @@ gr2t(gadouble *vals, gadouble gr, struct dt *dtim)
   gadouble v;
 
   /* Get constants associated with this conversion                   */
-  stim.yr = (gaint)(*vals + 0.1);
-  stim.mo = (gaint)(*(vals + 1) + 0.1);
-  stim.dy = (gaint)(*(vals + 2) + 0.1);
-  stim.hr = (gaint)(*(vals + 3) + 0.1);
-  stim.mn = (gaint)(*(vals + 4) + 0.1);
+  stim.yr = (gaint) (*vals + 0.1);
+  stim.mo = (gaint) (*(vals + 1) + 0.1);
+  stim.dy = (gaint) (*(vals + 2) + 0.1);
+  stim.hr = (gaint) (*(vals + 3) + 0.1);
+  stim.mn = (gaint) (*(vals + 4) + 0.1);
   moincr = vals + 5;
   mnincr = vals + 6;
 
@@ -331,10 +322,7 @@ gr2t(gadouble *vals, gadouble gr, struct dt *dtim)
           dtim->mn = -1 * dtim->mn;
           timsub(&stim, dtim);
         }
-      else
-        {
-          timadd(&stim, dtim);
-        }
+      else { timadd(&stim, dtim); }
       return;
 
       /* Do conversion if increment is in months.  Same as for minutes,
@@ -346,9 +334,9 @@ gr2t(gadouble *vals, gadouble gr, struct dt *dtim)
     {
       v = *moincr * (gr - 1.0);
       if (v < 0.0)
-        dtim->mo = (gaint)(v - 0.9999); /* round (sort of)       */
+        dtim->mo = (gaint) (v - 0.9999); /* round (sort of)       */
       else
-        dtim->mo = (gaint)(v + 0.0001);
+        dtim->mo = (gaint) (v + 0.0001);
       v = v - (gadouble) dtim->mo; /* Get fractional month  */
       if (dtim->mo < 0)
         {
@@ -359,20 +347,14 @@ gr2t(gadouble *vals, gadouble gr, struct dt *dtim)
         timadd(&stim, dtim);
       if (v < 0.0001) return; /* if fraction small, return       */
 
-      if (dtim->mo == 2 && qleap(dtim->yr))
-        {
-          v = v * 41760.0;
-        }
-      else
-        {
-          v = v * (gadouble) momn[dtim->mo];
-        }
+      if (dtim->mo == 2 && qleap(dtim->yr)) { v = v * 41760.0; }
+      else { v = v * (gadouble) momn[dtim->mo]; }
       stim = *dtim;
       dtim->yr = 0;
       dtim->mo = 0;
       dtim->dy = 0;
       dtim->hr = 0;
-      dtim->mn = (gaint)(v + 0.5);
+      dtim->mn = (gaint) (v + 0.5);
       timadd(&stim, dtim);
       return;
     }
@@ -382,7 +364,7 @@ gr2t(gadouble *vals, gadouble gr, struct dt *dtim)
    difference in minutes.   The calculation is time2 - time1, so
    if time2 is earlier than time1, the result is negative.           */
 
-gaint
+static gaint
 timdif(struct dt *dtim1, struct dt *dtim2)
 {
   gaint min1, min2, yr;
@@ -413,22 +395,10 @@ timdif(struct dt *dtim1, struct dt *dtim2)
 
   mo1 = dtim1->mo;
   mo2 = dtim2->mo;
-  if (qleap(dtim1->yr))
-    {
-      min1 = min1 + mnacul[mo1] + (dtim1->dy * 1440L) + (dtim1->hr * 60L) + dtim1->mn;
-    }
-  else
-    {
-      min1 = min1 + mnacum[mo1] + (dtim1->dy * 1440L) + (dtim1->hr * 60L) + dtim1->mn;
-    }
-  if (qleap(dtim2->yr))
-    {
-      min2 = min2 + mnacul[mo2] + (dtim2->dy * 1440L) + (dtim2->hr * 60L) + dtim2->mn;
-    }
-  else
-    {
-      min2 = min2 + mnacum[mo2] + (dtim2->dy * 1440L) + (dtim2->hr * 60L) + dtim2->mn;
-    }
+  if (qleap(dtim1->yr)) { min1 = min1 + mnacul[mo1] + (dtim1->dy * 1440L) + (dtim1->hr * 60L) + dtim1->mn; }
+  else { min1 = min1 + mnacum[mo1] + (dtim1->dy * 1440L) + (dtim1->hr * 60L) + dtim1->mn; }
+  if (qleap(dtim2->yr)) { min2 = min2 + mnacul[mo2] + (dtim2->dy * 1440L) + (dtim2->hr * 60L) + dtim2->mn; }
+  else { min2 = min2 + mnacum[mo2] + (dtim2->dy * 1440L) + (dtim2->hr * 60L) + dtim2->mn; }
   if (swap)
     return (min1 - min2);
   else
@@ -445,7 +415,7 @@ static const char *mons[12] = { "jan", "feb", "mar", "apr", "may", "jun", "jul",
    higher order missing values (usually from tmin in pst).  Lower order
    values are defaulted to be: dy = 1, hr = 0, mn = 0.              */
 
-char *
+static char *
 adtprs(char *ch, struct dt *def, struct dt *dtim)
 {
   gaint val, flag, i;
@@ -553,19 +523,16 @@ adtprs(char *ch, struct dt *def, struct dt *dtim)
         {
           /* use fullyear only if year 1 = 0001*/
           if (*(ch + 2) >= '0' && *(ch + 2) <= '9')
-            {
-              /*mfcmn.*/ fullyear = 1;
+            { /*mfcmn.*/
+              fullyear = 1;
             }
           else
-            {
-              /*mfcmn.*/ fullyear = 0;
+            { /*mfcmn.*/
+              fullyear = 0;
             }
           ch = intprs(ch, &val);
         }
-      else
-        {
-          val = def->yr;
-        }
+      else { val = def->yr; }
 
       /* turn off setting of < 100 years to 1900 or 2000 */
       if (/*mfcmn.*/ fullyear == 0)
@@ -600,7 +567,7 @@ adtprs(char *ch, struct dt *def, struct dt *dtim)
 
    Missing values are filled in with 0s.                             */
 
-char *
+static char *
 rdtprs(char *ch, struct dt *dtim)
 {
   gaint flag, val;
@@ -751,7 +718,7 @@ longprs(char *ch, long *val)
 /* Moves a pointer to the start of the next blank-delimited word
    in a string.  If not found, NULL is returned.                     */
 
-char *
+static char *
 nxtwrd(char *ch)
 {
 
@@ -769,7 +736,7 @@ nxtwrd(char *ch)
    Trailing blanks are removed, and the output string is terminated
    with '\0'.                                                         */
 
-void
+static void
 getstr(char *ch1, char *ch2, int len)
 {
   char *ch;
@@ -825,10 +792,7 @@ getdbl(char *ch, double *val)
 {
   char *pos = NULL;
   double res = ch ? strtod(ch, &pos) : 0.0;
-  if (pos == ch)
-    {
-      return NULL;
-    }
+  if (pos == ch) { return NULL; }
   else
     {
       *val = res;
@@ -927,7 +891,7 @@ gr2lev(gadouble *vals, gadouble gr)
   if (gr < 1.0) return (*(vals + 1) + (1.0 - gr) * (*(vals + 1) - *(vals + 2)));
   if (gr > *vals)
     {
-      i = (gaint)(*vals + 0.1);
+      i = (gaint) (*vals + 0.1);
       return (*(vals + i) + (gr - *vals) * (*(vals + i) - *(vals + i - 1)));
     }
   i = (gaint) gr;
@@ -943,7 +907,7 @@ lev2gr(gadouble *vals, gadouble lev)
 {
   gaint i, num;
   gadouble gr;
-  num = (gaint)(*vals + 0.1);
+  num = (gaint) (*vals + 0.1);
   for (i = 1; i < num; i++)
     {
       if ((lev >= *(vals + i) && lev <= *(vals + i + 1)) || (lev <= *(vals + i) && lev >= *(vals + i + 1)))
@@ -976,7 +940,7 @@ lev2gr(gadouble *vals, gadouble lev)
 
 /* Process linear scaling args */
 
-gaint
+static gaint
 deflin(char *ch, dsets_t *pfi, gaint dim, gaint flag)
 {
   gadouble *vals, v1, v2;
@@ -1023,7 +987,7 @@ err2:
 /* Process levels values in def record */
 /* Return codes:  -1 is memory allocation error, 1 is other error */
 
-gaint
+static gaint
 deflev(char *ch, char *rec, dsets_t *pfi, gaint dim)
 {
   gadouble *vvs, *vals, v1;
@@ -1082,7 +1046,7 @@ err3:
 /*  handle var name of the form longnm=>abbrv
     or just the abbrv with no long name */
 
-gaint
+static gaint
 getvnm(struct gavar *pvar, char *mrec)
 {
   gaint ib, i, j, k, len, flag;
@@ -1571,22 +1535,10 @@ gafndt(char *fn, struct dt *dtim, struct dt *dtimi, gadouble *vals, struct gachs
         }
     }
   *out = '\0';
-  if (eused == 1 && tused == 1)
-    {
-      *flag = 3; /* templating on E and T */
-    }
-  else if (eused == 1 && tused == 0)
-    {
-      *flag = 2; /* templating only on E */
-    }
-  else if (eused == 0 && tused == 1)
-    {
-      *flag = 1; /* templating only on T */
-    }
-  else
-    {
-      *flag = 0; /* no templating */
-    }
+  if (eused == 1 && tused == 1) { *flag = 3; /* templating on E and T */ }
+  else if (eused == 1 && tused == 0) { *flag = 2; /* templating only on E */ }
+  else if (eused == 0 && tused == 1) { *flag = 1; /* templating only on T */ }
+  else { *flag = 0; /* no templating */ }
   return (fnout);
 }
 
@@ -1671,16 +1623,10 @@ read_gradsdes(char *filename, dsets_t *pfi)
             }
           */
         }
-      else if (cmpwrd("byteswapped", rec))
-        {
-          pfi->bswap = 1;
-        }
+      else if (cmpwrd("byteswapped", rec)) { pfi->bswap = 1; }
       else if (cmpwrd("fileheader", rec))
         {
-          if ((ch = nxtwrd(rec)) == NULL)
-            {
-              gaprnt(1, "Description file warning: Missing fileheader length\n");
-            }
+          if ((ch = nxtwrd(rec)) == NULL) { gaprnt(1, "Description file warning: Missing fileheader length\n"); }
           else
             {
               ch = longprs(ch, &(pfi->fhdr));
@@ -1693,10 +1639,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
         }
       else if (cmpwrd("xyheader", rec))
         {
-          if ((ch = nxtwrd(rec)) == NULL)
-            {
-              gaprnt(1, "Description file warning: Missing xy grid header length\n");
-            }
+          if ((ch = nxtwrd(rec)) == NULL) { gaprnt(1, "Description file warning: Missing xy grid header length\n"); }
           else
             {
               ch = longprs(ch, &(pfi->xyhdr));
@@ -1705,18 +1648,12 @@ read_gradsdes(char *filename, dsets_t *pfi)
                   gaprnt(1, "xy grid header length invalid\n");
                   pfi->xyhdr = 0;
                 }
-              else
-                {
-                  pfi->xyhdr = pfi->xyhdr / 4;
-                }
+              else { pfi->xyhdr = pfi->xyhdr / 4; }
             }
         }
       else if (cmpwrd("format", rec) || cmpwrd("options", rec))
         {
-          if ((ch = nxtwrd(rec)) == NULL)
-            {
-              gaprnt(1, "Description file warning: Missing options keyword\n");
-            }
+          if ((ch = nxtwrd(rec)) == NULL) { gaprnt(1, "Description file warning: Missing options keyword\n"); }
           else
             {
               while (ch != NULL)
@@ -1737,10 +1674,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
                   else if (cmpwrd("pascals", ch))
                     pfi->pa2mb = 1;
 #endif
-                  else if (cmpwrd("365_day_calendar", ch))
-                    {
-                      pfi->calendar = 1;
-                    }
+                  else if (cmpwrd("365_day_calendar", ch)) { pfi->calendar = 1; }
                   else if (cmpwrd("big_endian", ch))
                     {
                       if (!BYTEORDER) pfi->bswap = 1;
@@ -1760,10 +1694,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
         }
       else if (cmpwrd("trailerbytes", rec))
         {
-          if ((ch = nxtwrd(rec)) == NULL)
-            {
-              gaprnt(1, "Trailerbytes record invalid\n");
-            }
+          if ((ch = nxtwrd(rec)) == NULL) { gaprnt(1, "Trailerbytes record invalid\n"); }
           else
             {
               ch = intprs(ch, &trlb);
@@ -1772,18 +1703,12 @@ read_gradsdes(char *filename, dsets_t *pfi)
                   gaprnt(1, "Trailerbytes record invalid\n");
                   trlb = 0;
                 }
-              else
-                {
-                  trlb = trlb / 4;
-                }
+              else { trlb = trlb / 4; }
             }
         }
       else if (cmpwrd("headerbytes", rec) || cmpwrd("theader", rec))
         {
-          if ((ch = nxtwrd(rec)) == NULL)
-            {
-              gaprnt(1, "headerbytes/theader record invalid\n");
-            }
+          if ((ch = nxtwrd(rec)) == NULL) { gaprnt(1, "headerbytes/theader record invalid\n"); }
           else
             {
               ch = intprs(ch, &hdrb);
@@ -1792,10 +1717,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
                   gaprnt(1, "headerbytes/theader record invalid\n");
                   hdrb = 0;
                 }
-              else
-                {
-                  hdrb = hdrb / 4;
-                }
+              else { hdrb = hdrb / 4; }
             }
         }
       /* Handle the chsub records.  time1, time2, then a string,  multiple times
@@ -1806,10 +1728,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
           pchsub = pfi->pchsub1;
           if (pchsub != NULL)
             {
-              while (pchsub->forw != NULL)
-                {
-                  pchsub = pchsub->forw; /* advance to end of chain */
-                }
+              while (pchsub->forw != NULL) { pchsub = pchsub->forw; /* advance to end of chain */ }
             }
           flag = 0;
           ch = mrec;
@@ -1853,21 +1772,12 @@ read_gradsdes(char *filename, dsets_t *pfi)
               pchsub->t1 = tim1;
               pchsub->t2 = tim2;
             }
-          if (flag)
-            {
-              gaprnt(1, "Description file warning: Invalid chsub record; Ignored\n");
-            }
+          if (flag) { gaprnt(1, "Description file warning: Invalid chsub record; Ignored\n"); }
         }
       else if (cmpwrd("title", rec))
         {
-          if ((ch = nxtwrd(mrec)) == NULL)
-            {
-              gaprnt(1, "Description file warning: Missing title string\n");
-            }
-          else
-            {
-              getstr(pfi->title, ch, MAX_NAMELEN);
-            }
+          if ((ch = nxtwrd(mrec)) == NULL) { gaprnt(1, "Description file warning: Missing title string\n"); }
+          else { getstr(pfi->title, ch, MAX_NAMELEN); }
         }
       else if (cmpwrd("dset", rec))
         {
@@ -1877,14 +1787,8 @@ read_gradsdes(char *filename, dsets_t *pfi)
               gaprnt(0, "Descriptor File Error:  Data file name is missing\n");
               goto err9;
             }
-          if (*ch == '^' || *ch == '$')
-            {
-              fnmexp(pfi->name, ch, filename);
-            }
-          else
-            {
-              getwrd(pfi->name, ch, MAX_NAMELEN);
-            }
+          if (*ch == '^' || *ch == '$') { fnmexp(pfi->name, ch, filename); }
+          else { getwrd(pfi->name, ch, MAX_NAMELEN); }
         }
       else if (cmpwrd("undef", rec))
         {
@@ -1927,7 +1831,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
               if (rc) goto err9;
               v2 = *(pfi->grvals[0]);
               v1 = *(pfi->grvals[0] + 1) + v2;
-              temp = v1 + ((gadouble)(pfi->dnum[0])) * v2;
+              temp = v1 + ((gadouble) (pfi->dnum[0])) * v2;
               temp = temp - 360.0;
               if (fabs(temp - v1) < 0.01) pfi->wrap = 1;
             }
@@ -2381,18 +2285,9 @@ read_gradsdes(char *filename, dsets_t *pfi)
       /* add the XY header to gsiz */
       if (pfi->xyhdr)
         {
-          if (pvar->dfrm == 1)
-            {
-              pfi->xyhdr = pfi->xyhdr * 4 / 1;
-            }
-          else if (pvar->dfrm == 2 || pvar->dfrm == -2)
-            {
-              pfi->xyhdr = pfi->xyhdr * 4 / 2;
-            }
-          else if (pfi->flt64)
-            {
-              pfi->xyhdr = pfi->xyhdr * 4 / 8;
-            }
+          if (pvar->dfrm == 1) { pfi->xyhdr = pfi->xyhdr * 4 / 1; }
+          else if (pvar->dfrm == 2 || pvar->dfrm == -2) { pfi->xyhdr = pfi->xyhdr * 4 / 2; }
+          else if (pfi->flt64) { pfi->xyhdr = pfi->xyhdr * 4 / 8; }
           pfi->gsiz = pfi->gsiz + pfi->xyhdr;
         }
 
@@ -2411,14 +2306,8 @@ read_gradsdes(char *filename, dsets_t *pfi)
       if (pfi->seqflg)
         {
           /* pad the grid size with 2 4-byte chunks */
-          if (pvar->dfrm == 1)
-            {
-              pfi->gsiz += 8;
-            }
-          else if (pvar->dfrm == 2 || pvar->dfrm == -2)
-            {
-              pfi->gsiz += 4;
-            }
+          if (pvar->dfrm == 1) { pfi->gsiz += 8; }
+          else if (pvar->dfrm == 2 || pvar->dfrm == -2) { pfi->gsiz += 4; }
           else
             {
               if (pfi->flt64)
@@ -2429,18 +2318,9 @@ read_gradsdes(char *filename, dsets_t *pfi)
           /* pad the header with 2 4-byte chunks*/
           if (hdrb > 0)
             {
-              if (pvar->dfrm == 1)
-                {
-                  hdrb = hdrb + 8;
-                }
-              else if (pvar->dfrm == 2 || pvar->dfrm == -2)
-                {
-                  hdrb = hdrb + 4;
-                }
-              else
-                {
-                  hdrb += 2;
-                }
+              if (pvar->dfrm == 1) { hdrb = hdrb + 8; }
+              else if (pvar->dfrm == 2 || pvar->dfrm == -2) { hdrb = hdrb + 4; }
+              else { hdrb += 2; }
             }
           /* how far we have to go into the file before getting to 1st var */
           if (pvar->dfrm == 1)
@@ -2474,10 +2354,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
 
       for (i = 1; i < pfi->vnum; i++)
         {
-          if (pvar->var_t)
-            {
-              acum = acum + levs * (pfi->gsiz) * (pfi->dnum[3]);
-            }
+          if (pvar->var_t) { acum = acum + levs * (pfi->gsiz) * (pfi->dnum[3]); }
           else
             {
               acum = acum + (levs * pfi->gsiz);
@@ -2510,8 +2387,8 @@ read_gradsdes(char *filename, dsets_t *pfi)
   /* set the global calendar and check if we are trying to change with a new
      file... we do this here to set the calandar for templating */
   if (/*mfcmn.*/ cal365 < 0)
-    {
-      /*mfcmn.*/ cal365 = pfi->calendar;
+    { /*mfcmn.*/
+      cal365 = pfi->calendar;
     }
   else
     {
@@ -2584,10 +2461,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
               gaprnt(1, "   DSET entry contains no substitution templates.\n");
               pfi->tmplat = 1;
             }
-          else
-            {
-              pfi->tmplat = flag;
-            }
+          else { pfi->tmplat = flag; }
           /* for non-indexed, non-netcdf/hdf, gridded data */
           if (pfi->type == 1)
             { /* gridded data   */
@@ -2635,10 +2509,7 @@ read_gradsdes(char *filename, dsets_t *pfi)
                   gree(ch, "f176");
                   ch = pos;
                 }
-              else
-                {
-                  gree(pos, "f176a");
-                }
+              else { gree(pos, "f176a"); }
               pfi->fnums[+t - 1] = j;
             }
           gree(ch, "f177");
