@@ -7,16 +7,8 @@
 #ifndef MODULES_H
 #define MODULES_H
 
-#include <iostream>
-#include <map>
-#include <array>
 #include <vector>
 
-#include <functional>
-#include <memory>
-#include "cdo_module.h"
-#include "process.h"
-
 /***
   type definition for module functions loaded from a custom module
   */
