@@ -15,14 +15,12 @@ extern "C"
 #include <cassert>
 
 HpOrder
-hp_get_order(const std::string &orderName)
+hp_get_order(std::string const &orderName)
 {
-  // clang-format off
-  if      (orderName == "xy")     return HpOrder::XY;
-  else if (orderName == "ring")   return HpOrder::Ring;
-  else if (orderName == "nest")   return HpOrder::Nested;
-  else if (orderName == "nested") return HpOrder::Nested;
-  // clang-format on
+  if (orderName == "xy") return HpOrder::XY;
+  if (orderName == "ring") return HpOrder::Ring;
+  if (orderName == "nest") return HpOrder::Nested;
+  if (orderName == "nested") return HpOrder::Nested;
   return HpOrder::Undef;
 }
 
@@ -36,8 +34,8 @@ hp_xy_to_xy(int64_t index, int nside)
 int64_t
 hp_lonlat_to_index(HpParams hpParams, double xval, double yval)
 {
-  auto nside = hpParams.get_nside();
-  auto order = hpParams.get_order();
+  auto nside = hpParams.nside();
+  auto order = hpParams.order();
 
   // clang-format off
   auto xy_to_order = (order == HpOrder::Ring)   ? &healpixl_xy_to_ring :
@@ -50,8 +48,8 @@ hp_lonlat_to_index(HpParams hpParams, double xval, double yval)
 void
 hp_index_to_lonlat(HpParams hpParams, int64_t index, double *xval, double *yval)
 {
-  auto nside = hpParams.get_nside();
-  auto order = hpParams.get_order();
+  auto nside = hpParams.nside();
+  auto order = hpParams.order();
 
   // clang-format off
   auto order_to_xy = (order == HpOrder::Ring)   ? &healpixl_ring_to_xy :
@@ -64,8 +62,8 @@ hp_index_to_lonlat(HpParams hpParams, int64_t index, double *xval, double *yval)
 void
 hp_get_neighbours(HpParams hpParams, int64_t index, int64_t *neighbours)
 {
-  auto nside = hpParams.get_nside();
-  auto order = hpParams.get_order();
+  auto nside = hpParams.nside();
+  auto order = hpParams.order();
 
   // clang-format off
   auto order_to_xy = (order == HpOrder::Ring)   ? &healpixl_ring_to_xy :
@@ -84,10 +82,10 @@ hp_get_neighbours(HpParams hpParams, int64_t index, int64_t *neighbours)
 }
 
 void
-hp_bilinear_interpolate_weights(HpParams hpParams, double lon, double lat, size_t *indices, double *weights)
+hp_bilinear_interpolate_weights(HpParams hpParams, double lon, double lat, size_t (&indices)[4], double (&weights)[4])
 {
-  auto nside = hpParams.get_nside();
-  auto order = hpParams.get_order();
+  auto nside = hpParams.nside();
+  auto order = hpParams.order();
 
   // clang-format off
   auto xy_to_order = (order == HpOrder::Ring)   ? &healpixl_xy_to_ring :
@@ -103,6 +101,22 @@ hp_bilinear_interpolate_weights(HpParams hpParams, double lon, double lat, size_
     for (int i = 0; i < 4; ++i) indices[i] = xy_to_order(healpixl_ring_to_xy(ringIndices[i], nside), nside);
 }
 
+static inline void
+hp_generate_kernel(int64_t xyIndex, int nside, int64_t index, double *xvals, double *yvals, bool withBounds, double *xbounds,
+                   double *ybounds)
+{
+  healpixl_to_radec(xyIndex, nside, 0.5, 0.5, &xvals[index], &yvals[index]);
+
+  if (withBounds)
+  {
+    auto index4 = index * 4;
+    healpixl_to_radec(xyIndex, nside, 0.0, 0.0, &xbounds[index4 + 0], &ybounds[index4 + 0]);
+    healpixl_to_radec(xyIndex, nside, 1.0, 0.0, &xbounds[index4 + 1], &ybounds[index4 + 1]);
+    healpixl_to_radec(xyIndex, nside, 1.0, 1.0, &xbounds[index4 + 2], &ybounds[index4 + 2]);
+    healpixl_to_radec(xyIndex, nside, 0.0, 1.0, &xbounds[index4 + 3], &ybounds[index4 + 3]);
+  }
+}
+
 void
 hp_generate_coords(HpOrder order, int nside, int64_t nvals, double *xvals, double *yvals, bool withBounds, double *xbounds,
                    double *ybounds)
@@ -116,33 +130,43 @@ hp_generate_coords(HpOrder order, int nside, int64_t nvals, double *xvals, doubl
 #pragma omp parallel for if (nvals > 99999) default(shared) schedule(static)
 #endif
   for (int64_t index = 0; index < nvals; index++)
-    {
-      auto xyIndex = order_to_xy(index, nside);
-      healpixl_to_radec(xyIndex, nside, 0.5, 0.5, &xvals[index], &yvals[index]);
+  {
+    auto xyIndex = order_to_xy(index, nside);
+    hp_generate_kernel(xyIndex, nside, index, xvals, yvals, withBounds, xbounds, ybounds);
+  }
+}
 
-      if (withBounds)
-        {
-          auto index4 = index * 4;
-          healpixl_to_radec(xyIndex, nside, 0.0, 0.0, &xbounds[index4 + 0], &ybounds[index4 + 0]);
-          healpixl_to_radec(xyIndex, nside, 1.0, 0.0, &xbounds[index4 + 1], &ybounds[index4 + 1]);
-          healpixl_to_radec(xyIndex, nside, 1.0, 1.0, &xbounds[index4 + 2], &ybounds[index4 + 2]);
-          healpixl_to_radec(xyIndex, nside, 0.0, 1.0, &xbounds[index4 + 3], &ybounds[index4 + 3]);
-        }
-    }
+void
+hp_generate_coords_indices(HpOrder order, int nside, int64_t nvals, double *xvals, double *yvals, bool withBounds, double *xbounds,
+                           double *ybounds, int64_t *indices)
+{
+  // clang-format off
+  auto order_to_xy = (order == HpOrder::Ring)   ? &healpixl_ring_to_xy :
+                     (order == HpOrder::Nested) ? &healpixl_nested_to_xy : &hp_xy_to_xy;
+  // clang-format on
+
+#ifdef _OPENMP
+#pragma omp parallel for if (nvals > 99999) default(shared) schedule(static)
+#endif
+  for (int64_t index = 0; index < nvals; index++)
+  {
+    auto xyIndex = order_to_xy(indices[index], nside);
+    hp_generate_kernel(xyIndex, nside, index, xvals, yvals, withBounds, xbounds, ybounds);
+  }
 }
 
 void
 hp_generate_latitudes(int nside, std::vector<double> &latitudes)
 {
   for (int ringNumber = 1; ringNumber < 4 * nside; ringNumber++)
-    {
-      // Find the longitude/latitude and ring index of this pixel
-      auto ringIndex = healpixl_compose_ring(ringNumber, 0, nside);
-      auto xyIndex = healpixl_ring_to_xy(ringIndex, nside);
-      double lon, lat;
-      healpixl_to_radec(xyIndex, nside, 0.5, 0.5, &lon, &lat);
-      latitudes[ringNumber - 1] = lat;
-    }
+  {
+    // Find the longitude/latitude and ring index of this pixel
+    auto ringIndex = healpixl_compose_ring(ringNumber, 0, nside);
+    auto xyIndex = healpixl_ring_to_xy(ringIndex, nside);
+    double lon, lat;
+    healpixl_to_radec(xyIndex, nside, 0.5, 0.5, &lon, &lat);
+    latitudes[ringNumber - 1] = lat;
+  }
 }
 
 static int
@@ -161,8 +185,8 @@ hp_generate_ring_indices(HpParams hpParams, size_t gridsize, std::vector<int> &r
 {
   assert(gridsize <= INT_MAX && "Large grid size unsupported!");
 
-  auto nside = hpParams.get_nside();
-  auto order = hpParams.get_order();
+  auto nside = hpParams.nside();
+  auto order = hpParams.order();
 
   // clang-format off
   auto xy_to_order = (order == HpOrder::Ring)   ? &healpixl_xy_to_ring :
@@ -175,21 +199,21 @@ hp_generate_ring_indices(HpParams hpParams, size_t gridsize, std::vector<int> &r
 
   int index = 0;
   for (int ringNumber = 1; ringNumber < 4 * nside; ringNumber++)
-    {
-      auto numInRing = num_in_ring(nside, ringNumber);
-      ringRows[ringNumber - 1] = numInRing;
+  {
+    auto numInRing = num_in_ring(nside, ringNumber);
+    ringRows[ringNumber - 1] = numInRing;
 
-      if (order != HpOrder::Ring)
-        {
-          for (int i = 0; i < numInRing; i++)
-            {
-              // Find the ring index of this pixel
-              int ringIndex = healpixl_compose_ring(ringNumber, i, nside);
-              if (order != HpOrder::Ring) ringIndex = xy_to_order(healpixl_ring_to_xy(ringIndex, nside), nside);
-              ringIndices[index++] = ringIndex;
-            }
-        }
+    if (order != HpOrder::Ring)
+    {
+      for (int i = 0; i < numInRing; i++)
+      {
+        // Find the ring index of this pixel
+        int ringIndex = healpixl_compose_ring(ringNumber, i, nside);
+        if (order != HpOrder::Ring) ringIndex = xy_to_order(healpixl_ring_to_xy(ringIndex, nside), nside);
+        ringIndices[index++] = ringIndex;
+      }
     }
+  }
 }
 
 template <typename T>
@@ -199,10 +223,10 @@ hp_ring_to_nested(int nside, size_t gridsize, T *arrayIn, T *arrayOut)
   assert(gridsize <= INT_MAX && "Large grid size unsupported!");
 
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      auto nestedIndex = healpixl_xy_to_nested(healpixl_ring_to_xy(i, nside), nside);
-      arrayOut[nestedIndex] = arrayIn[i];
-    }
+  {
+    auto nestedIndex = healpixl_xy_to_nested(healpixl_ring_to_xy(i, nside), nside);
+    arrayOut[nestedIndex] = arrayIn[i];
+  }
 }
 
 // Explicit instantiation
@@ -216,10 +240,10 @@ hp_nested_to_ring(int nside, size_t gridsize, T *arrayIn, T *arrayOut)
   assert(gridsize <= INT_MAX && "Large grid size unsupported!");
 
   for (size_t i = 0; i < gridsize; ++i)
-    {
-      auto ringIndex = healpixl_xy_to_ring(healpixl_nested_to_xy(i, nside), nside);
-      arrayOut[ringIndex] = arrayIn[i];
-    }
+  {
+    auto ringIndex = healpixl_xy_to_ring(healpixl_nested_to_xy(i, nside), nside);
+    arrayOut[ringIndex] = arrayIn[i];
+  }
 }
 
 // Explicit instantiation
