@@ -10,7 +10,7 @@ typedef std::vector<std::string_view> CdoHelp;
 
 extern const CdoHelp InfoHelp;
 extern const CdoHelp SinfoHelp;
-extern const CdoHelp XSinfoHelp;
+extern const CdoHelp XsinfoHelp;
 extern const CdoHelp DiffHelp;
 extern const CdoHelp NinfoHelp;
 extern const CdoHelp ShowinfoHelp;
@@ -48,7 +48,7 @@ extern const CdoHelp SelsurfaceHelp;
 extern const CdoHelp CondHelp;
 extern const CdoHelp Cond2Help;
 extern const CdoHelp CondcHelp;
-extern const CdoHelp MapReduceHelp;
+extern const CdoHelp MapreduceHelp;
 extern const CdoHelp CompHelp;
 extern const CdoHelp CompcHelp;
 extern const CdoHelp YmoncompHelp;
@@ -132,7 +132,7 @@ extern const CdoHelp RegresHelp;
 extern const CdoHelp DetrendHelp;
 extern const CdoHelp TrendHelp;
 extern const CdoHelp TrendarithHelp;
-extern const CdoHelp EOFsHelp;
+extern const CdoHelp EofHelp;
 extern const CdoHelp EofcoeffHelp;
 extern const CdoHelp RemapbilHelp;
 extern const CdoHelp RemapbicHelp;
@@ -156,7 +156,6 @@ extern const CdoHelp WindHelp;
 extern const CdoHelp FourierHelp;
 extern const CdoHelp ImportbinaryHelp;
 extern const CdoHelp ImportcmsafHelp;
-extern const CdoHelp ImportamsrHelp;
 extern const CdoHelp InputHelp;
 extern const CdoHelp OutputHelp;
 extern const CdoHelp OutputtabHelp;
@@ -171,8 +170,8 @@ extern const CdoHelp ReplacevaluesHelp;
 extern const CdoHelp GetgridcellHelp;
 extern const CdoHelp VargenHelp;
 extern const CdoHelp TimsortHelp;
-extern const CdoHelp WindTransHelp;
-extern const CdoHelp RotuvbHelp;
+extern const CdoHelp WindtransHelp;
+extern const CdoHelp RotuvHelp;
 extern const CdoHelp MrotuvbHelp;
 extern const CdoHelp MastrfuHelp;
 extern const CdoHelp PressureHelp;
@@ -187,48 +186,48 @@ extern const CdoHelp StrwinHelp;
 extern const CdoHelp StrbreHelp;
 extern const CdoHelp StrgalHelp;
 extern const CdoHelp HurrHelp;
-extern const CdoHelp CMORliteHelp;
+extern const CdoHelp CmorliteHelp;
 extern const CdoHelp VerifygridHelp;
 extern const CdoHelp HealpixHelp;
-extern const CdoHelp NCL_windHelp;
-extern const CdoHelp CMORHelp;
+extern const CdoHelp Ncl_windHelp;
+extern const CdoHelp CmorHelp;
 extern const CdoHelp MagplotHelp;
 extern const CdoHelp MagvectorHelp;
 extern const CdoHelp MaggraphHelp;
-extern const CdoHelp EcaCddHelp;
-extern const CdoHelp EcaCfdHelp;
-extern const CdoHelp EcaCsuHelp;
-extern const CdoHelp EcaCwdHelp;
-extern const CdoHelp EcaCwdiHelp;
-extern const CdoHelp EcaCwfiHelp;
-extern const CdoHelp EcaEtrHelp;
-extern const CdoHelp EcaFdHelp;
-extern const CdoHelp EcaGslHelp;
-extern const CdoHelp EcaHdHelp;
-extern const CdoHelp EcaHwdiHelp;
-extern const CdoHelp EcaHwfiHelp;
-extern const CdoHelp EcaIdHelp;
-extern const CdoHelp EcaR75pHelp;
-extern const CdoHelp EcaR75ptotHelp;
-extern const CdoHelp EcaR90pHelp;
-extern const CdoHelp EcaR90ptotHelp;
-extern const CdoHelp EcaR95pHelp;
-extern const CdoHelp EcaR95ptotHelp;
-extern const CdoHelp EcaR99pHelp;
-extern const CdoHelp EcaR99ptotHelp;
-extern const CdoHelp EcaPdHelp;
-extern const CdoHelp EcaRr1Help;
-extern const CdoHelp EcaRx1dayHelp;
-extern const CdoHelp EcaRx5dayHelp;
-extern const CdoHelp EcaSdiiHelp;
-extern const CdoHelp EcaSuHelp;
-extern const CdoHelp EcaTg10pHelp;
-extern const CdoHelp EcaTg90pHelp;
-extern const CdoHelp EcaTn10pHelp;
-extern const CdoHelp EcaTn90pHelp;
-extern const CdoHelp EcaTrHelp;
-extern const CdoHelp EcaTx10pHelp;
-extern const CdoHelp EcaTx90pHelp;
-extern const CdoHelp EcaEtccdiHelp;
+extern const CdoHelp Eca_cddHelp;
+extern const CdoHelp Eca_cfdHelp;
+extern const CdoHelp Eca_csuHelp;
+extern const CdoHelp Eca_cwdHelp;
+extern const CdoHelp Eca_cwdiHelp;
+extern const CdoHelp Eca_cwfiHelp;
+extern const CdoHelp Eca_etrHelp;
+extern const CdoHelp Eca_fdHelp;
+extern const CdoHelp Eca_gslHelp;
+extern const CdoHelp Eca_hdHelp;
+extern const CdoHelp Eca_hwdiHelp;
+extern const CdoHelp Eca_hwfiHelp;
+extern const CdoHelp Eca_idHelp;
+extern const CdoHelp Eca_r75pHelp;
+extern const CdoHelp Eca_r75ptotHelp;
+extern const CdoHelp Eca_r90pHelp;
+extern const CdoHelp Eca_r90ptotHelp;
+extern const CdoHelp Eca_r95pHelp;
+extern const CdoHelp Eca_r95ptotHelp;
+extern const CdoHelp Eca_r99pHelp;
+extern const CdoHelp Eca_r99ptotHelp;
+extern const CdoHelp Eca_pdHelp;
+extern const CdoHelp Eca_rr1Help;
+extern const CdoHelp Eca_rx1dayHelp;
+extern const CdoHelp Eca_rx5dayHelp;
+extern const CdoHelp Eca_sdiiHelp;
+extern const CdoHelp Eca_suHelp;
+extern const CdoHelp Eca_tg10pHelp;
+extern const CdoHelp Eca_tg90pHelp;
+extern const CdoHelp Eca_tn10pHelp;
+extern const CdoHelp Eca_tn90pHelp;
+extern const CdoHelp Eca_trHelp;
+extern const CdoHelp Eca_tx10pHelp;
+extern const CdoHelp Eca_tx90pHelp;
+extern const CdoHelp Eca_etccdiHelp;
 
 #endif
