@@ -15,7 +15,8 @@
 struct pipe_t
 {
 public:
-  pipe_t();
+  pipe_t() { pipe_init(); }
+
   void pipe_init();
 
   int pipe_inq_vlist(int &vlistID);
@@ -24,19 +25,19 @@ public:
   int pipe_inq_timestep(int p_tsID);
   void pipe_def_timestep(int p_vlistID, int tsID);
 
-  int pipe_inq_record(int *varID, int *levelID);
-  void pipe_def_record(int p_varId, int p_levelID);
+  int pipe_inq_field(int *varID, int *levelID);
+  void pipe_def_field(int p_varId, int p_levelID);
 
-  void pipe_write_record(double *p_data, size_t p_nmiss);
-  void pipe_write_record(float *p_data, size_t p_nmiss);
-  void pipe_write_record(Field *p_data, size_t p_nmiss);
+  void pipe_write_field(const double *const p_data, size_t p_numMissVals);
+  void pipe_write_field(const float *const p_data, size_t p_numMissVals);
+  void pipe_write_field(const Field *const p_data, size_t p_numMissVals);
 
-  size_t pipe_read_record(int p_vlistID, double *data, size_t *nmiss);
-  size_t pipe_read_record(int p_vlistID, float *data, size_t *nmiss);
-  size_t pipe_read_record(int p_vlistID, Field *data, size_t *nmiss);
+  size_t pipe_read_field(int p_vlistID, double *data, size_t *numMissVals);
+  size_t pipe_read_field(int p_vlistID, float *data, size_t *numMissVals);
+  size_t pipe_read_field(int p_vlistID, Field *data, size_t *numMissVals);
 
-  size_t pipe_read_pipe_record(double *data, int vlistID, size_t *p_nmiss);
-  size_t pipe_read_pipe_record(float *data, int vlistID, size_t *p_nmiss);
+  size_t pipe_read_pipe_field(double *data, int vlistID, size_t *p_numMissVals);
+  size_t pipe_read_pipe_field(float *data, int vlistID, size_t *p_numMissVals);
 
   void pipe_set_name(int processID, int inputIDX);
   void close();
@@ -46,12 +47,12 @@ public:
   bool hasdata;
 
   int varID, levelID;
-  int recIDr, recIDw, tsIDr, tsIDw;
+  int fieldIDr, fieldIDw, tsIDr, tsIDw;
 
-  size_t nmiss;
-  int nrecs;
+  size_t numMissVals;
+  int numFields;
 
-  bool data_is_float;
+  bool dataIsFloat;
   double *data_d;
   float *data_f;
 
