@@ -10,6 +10,7 @@
 #include <list>
 #include <vector>
 #include <string>
+#include <string_view>
 
 #include "listbuffer.h"
 #include "namelist.h"
@@ -17,7 +18,7 @@
 
 struct KeyValues
 {
-  int nvalues = 0;
+  int nvalues{ 0 };
   std::string key;
   std::vector<std::string> values;
 };
@@ -33,12 +34,12 @@ KVList : public std::list<KeyValues>
 public:
   std::string name;
 
-  void print(FILE *fp = stderr) const;
-  int parse_arguments(const std::vector<std::string> &argv);
-  const KeyValues *search(const std::string &key) const;
-  void remove(const std::string &inkey);
-  void append(const std::string &key, const std::vector<std::string> &values, int nvalues);
-  const std::string get_first_value(const std::string &key, const std::string &replacer);
+  void print(std::FILE *fp = stderr) const;
+  int parse_arguments(std::vector<std::string> const &argv);
+  const KeyValues *search(std::string const &key) const;
+  void remove(std::string const &inkey);
+  void append(std::string const &key, std::vector<std::string> const &values, int nvalues);
+  const std::string get_first_value(std::string const &key, std::string const &replacer);
 };
 
 // clang-format off
@@ -50,16 +51,16 @@ PMList : public std::list<KVList>
 // clang-format on
 {
 public:
-  const KVList *searchKVListVentry(const std::string &key, const std::string &value, const std::vector<std::string> &entry);
-  const KVList *getKVListVentry(const std::vector<std::string> &entry);
-  void print(FILE *fp = stderr);
-  void read_namelist(FILE *fp, const char *name);
-  void read_cmor_table(FILE *fp, const char *name);
+  const KVList *searchKVListVentry(std::string const &key, std::string const &value, std::vector<std::string> const &entry);
+  const KVList *getKVListVentry(std::vector<std::string> const &entry);
+  void print(std::FILE *fp = stderr);
+  void read_namelist(std::FILE *fp, std::string_view name);
+  void read_cmor_table(std::FILE *fp, std::string_view name);
 };
 
 void mapvar(int vlistID, int varID, const KeyValues &kv, CmorVar &cmorVar, bool &hasValidMin, bool &hasValidMax, int ptab,
             bool isnPtmodeName);
 int parse_namelist(PMList &pmlist, NamelistParser &parser, char *buf, bool cdocmor);
-int parse_list_buffer(NamelistParser &p, ListBuffer &listBuffer);
+int parse_list_buffer(NamelistParser &p, ListBuffer const &listBuffer);
 
 #endif
