@@ -42,7 +42,7 @@ fill_src_indices(bool isCyclic, long nx, long ny, long ii, long jj, long k, size
 }
 
 void
-PointsearchReg2d::compute_point(size_t index, double_t (&xyz)[3])
+PointsearchReg2d::compute_point(size_t index, double (&xyz)[3])
 {
   auto iy = index / m_nx;
   auto ix = index - iy * m_nx;
