@@ -22,24 +22,24 @@ extern "C"
 class PointsearchSpherepart : public PointsearchStrategy
 {
 public:
-  PointsearchSpherepart(const Varray<double> &lons, const Varray<double> &lats, const PointsearchParams &params) : m_params(params)
+  PointsearchSpherepart(Varray<double> const &lons, Varray<double> const &lats, const PointsearchParams &params) : m_params(params)
   {
     create(lons, lats);
   }
-  ~PointsearchSpherepart()
+  ~PointsearchSpherepart() override
   {
     if (m_yacPointSearch) yac_delete_point_sphere_part_search(m_yacPointSearch);
   }
 
   size_t
-  search_nearest(const PointLonLat &pointLL, size_t *index, double *dist) override
+  search_nearest(PointLonLat const &pointLL, size_t *index, double *dist) override
   {
     if (m_yacPointSearch == nullptr) return 0;
 
     auto searchArcRadius = chord_to_arc_length(m_params.searchRadius);
 
     double tgtPoint[3];
-    gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), tgtPoint);
+    gcLLtoXYZ(pointLL.lon(), pointLL.lat(), tgtPoint);
 
     if (!m_params.extrapolation)
       for (int i = 0; i < 3; ++i)
@@ -55,16 +55,16 @@ public:
 
     size_t numIndices = 0;
     if (num_local_point_ids > 0)
+    {
+      *dist = std::acos(cos_angle);
+      if (*dist <= searchArcRadius)
       {
-        *dist = std::acos(cos_angle);
-        if (*dist <= searchArcRadius)
-          {
-            numIndices = 1;
-            *index = local_point_ids[0];
-            for (size_t i = 1; i < num_local_point_ids; ++i)
-              if (local_point_ids[i] < *index) *index = local_point_ids[i];
-          }
+        numIndices = 1;
+        *index = local_point_ids[0];
+        for (size_t i = 1; i < num_local_point_ids; ++i)
+          if (local_point_ids[i] < *index) *index = local_point_ids[i];
       }
+    }
 
     if (local_point_ids) free(local_point_ids);
 
@@ -72,7 +72,7 @@ public:
   }
 
   size_t
-  search_qnearest(const PointLonLat &pointLL, size_t nnn, size_t *indices, double *dist) override
+  search_qnearest(PointLonLat const &pointLL, size_t nnn, size_t *indices, double *dist) override
   {
     size_t numIndices = 0;
 
@@ -81,7 +81,7 @@ public:
     auto searchArcRadius = chord_to_arc_length(m_params.searchRadius);
 
     double tgtPoint[3];
-    gcLLtoXYZ(pointLL.get_lon(), pointLL.get_lat(), tgtPoint);
+    gcLLtoXYZ(pointLL.lon(), pointLL.lat(), tgtPoint);
 
     if (!m_params.extrapolation)
       for (int i = 0; i < 3; ++i)
@@ -98,20 +98,20 @@ public:
                                      &local_point_ids, &local_point_ids_array_size, &num_local_point_ids);
 
     if (num_local_point_ids > 0)
+    {
+      auto maxIndices = (num_local_point_ids < nnn) ? num_local_point_ids : nnn;
+      numIndices = 0;
+      for (size_t i = 0; i < maxIndices; ++i)
       {
-        auto maxIndices = (num_local_point_ids < nnn) ? num_local_point_ids : nnn;
-        numIndices = 0;
-        for (size_t i = 0; i < maxIndices; ++i)
-          {
-            auto angle = std::acos(cos_angles[i]);
-            if (angle < searchArcRadius)
-              {
-                indices[numIndices] = local_point_ids[i];
-                dist[numIndices] = angle;
-                numIndices++;
-              }
-          }
+        auto angle = std::acos(cos_angles[i]);
+        if (angle < searchArcRadius)
+        {
+          indices[numIndices] = local_point_ids[i];
+          dist[numIndices] = angle;
+          numIndices++;
+        }
       }
+    }
 
     if (cos_angles) free(cos_angles);
     if (local_point_ids) free(local_point_ids);
@@ -128,7 +128,7 @@ private:
   const PointsearchParams &m_params;
 
   void
-  create(const Varray<double> &lons, const Varray<double> &lats)
+  create(Varray<double> const &lons, Varray<double> const &lats)
   {
     auto n = lons.size();
     m_pointsXYZ = std::make_unique<double[][3]>(n);
@@ -140,12 +140,12 @@ private:
 #pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[ : 3]) reduction(max : max[ : 3])
 #endif
     for (size_t i = 0; i < n; ++i)
-      {
-        auto &pointXYZ = m_pointsXYZ[i];
-        gcLLtoXYZ(lons[i], lats[i], pointXYZ);
-        min_point(min, pointXYZ);
-        max_point(max, pointXYZ);
-      }
+    {
+      auto &pointXYZ = m_pointsXYZ[i];
+      gcLLtoXYZ(lons[i], lats[i], pointXYZ);
+      min_point(min, pointXYZ);
+      max_point(max, pointXYZ);
+    }
 
     if (!m_params.useBoundBox) min[0] = min[1] = min[2] = -1;
     if (!m_params.useBoundBox) max[0] = max[1] = max[2] = 1;
