@@ -24,6 +24,7 @@
 #endif
 
 #include <cstdio>
+#include <cstdlib>
 #include <string>
 #include <sstream>
 
@@ -58,7 +59,7 @@ Process::replace_alias(std::string const &p_calledBy, const CdoModule &p_module)
   return originalName;
 }
 
-Process::Process(int p_ID, std::string const &p_operatorName, const std::vector<std::string> &p_arguments,
+Process::Process(int p_ID, std::string const &p_operatorName, std::vector<std::string> const &p_arguments,
                  const CdoModule &p_module)
     : arguments(p_module.arguments), m_ID(p_ID), m_module(p_module), m_oargv(p_arguments)
 {
@@ -104,10 +105,10 @@ Process::get_operator_id()
 
   Debug(PROCESS, "searching for %s", operatorName);
   for (size_t operID = 0; operID < m_module.operators.size(); operID++)
-    {
-      Debug(PROCESS, "comparing  %s and %s", operatorName, m_module.operators[operID].name);
-      if (operatorName == m_module.operators[operID].name) return operID;
-    }
+  {
+    Debug(PROCESS, "comparing  %s and %s", operatorName, m_module.operators[operID].name);
+    if (operatorName == m_module.operators[operID].name) return operID;
+  }
 
   cdo_abort("Operator not callable by this name! Name is: %s", operatorName);
 
@@ -221,18 +222,18 @@ Process::start_thread()
   size_t stacksize = 0;
   status = pthread_attr_getstacksize(&attr, &stacksize);
   if (stacksize < 2097152)
-    {
-      stacksize = 2097152;
-      pthread_attr_setstacksize(&attr, stacksize);
-    }
+  {
+    stacksize = 2097152;
+    pthread_attr_setstacksize(&attr, stacksize);
+  }
 
   pthread_t thrID;
   auto rval = pthread_create(&thrID, &attr, execute, this);
   if (rval != 0)
-    {
-      errno = rval;
-      cdo_sys_error("pthread_create failed for '%s'", operatorName);
-    }
+  {
+    errno = rval;
+    cdo_sys_error("pthread_create failed for '%s'", operatorName);
+  }
 
   return thrID;
 }
@@ -243,9 +244,9 @@ bool
 Process::has_out_stream(CdoStreamID p_streamID)
 {
   for (auto const &streamID : outputStreams)
-    {
-      if (streamID == p_streamID) return true;
-    }
+  {
+    if (streamID == p_streamID) return true;
+  }
   return false;
 }
 
@@ -253,9 +254,9 @@ bool
 Process::has_in_stream(CdoStreamID p_streamID)
 {
   for (auto const &streamID : inputStreams)
-    {
-      if (streamID == p_streamID) return true;
-    }
+  {
+    if (streamID == p_streamID) return true;
+  }
   return false;
 }
 
@@ -264,10 +265,10 @@ Process::inq_nvals()
 {
   size_t nvals = 0;
   for (size_t i = 0, n = inputStreams.size(); i < n; ++i)
-    {
-      Debug(PROCESS, "Inquiring nvals from instream %s", inputStreams[i]->m_name);
-      nvals += inputStreams[i]->getNvals();
-    }
+  {
+    Debug(PROCESS, "Inquiring nvals from instream %s", inputStreams[i]->m_name);
+    nvals += inputStreams[i]->getNvals();
+  }
   return nvals;
 }
 
@@ -305,10 +306,10 @@ Process::create_output()
 
 #ifdef HAVE_NETCDF
   if (auto retVal = nc_create_mem("test_name", 0, 4096, &ncid))
-    {
-      printf("Error: %s\n", nc_strerror(retVal));
-      exit(1);
-    }
+  {
+    printf("Error: %s\n", nc_strerror(retVal));
+    std::exit(1);
+  }
   if (PROCESS) std::cout << "created ncid: " << ncid << std::endl;
 
   int streamID = streamOpenWriteNCMem(ncid);
@@ -330,10 +331,10 @@ Process::open_write(std::string const &p_filename, int filetype)
 
   if (write_mode == ProcessWriteMode::FILEIO) { add_file_out_stream(p_filename); }
   else if (write_mode == ProcessWriteMode::MEMORY)
-    {
-      auto [fid, sid] = create_output();
-      add_mem_out_stream(fid, sid);
-    }
+  {
+    auto [fid, sid] = create_output();
+    add_mem_out_stream(fid, sid);
+  }
 
   const auto pstreamID = outputStreams.back()->open_write(filetype);
   if (pstreamID == -1) cdo_abort("Could not create pstream for file: %s", p_filename);
