@@ -39,7 +39,7 @@ private:
   int m_numProcesses = 0;
   int m_numProcessesActive = 0;
 
-  const std::shared_ptr<Process> create_process(const std::string &operatorName, const std::vector<std::string> &arguments);
+  const std::shared_ptr<Process> create_process(std::string const &operatorName, std::vector<std::string> const &arguments);
   void handle_child_construction(std::shared_ptr<Process> &parent, const std::shared_ptr<Node> &child);
 
 public:
