@@ -19,7 +19,7 @@ struct Regions
   size_t numSegments = 0;
 };
 
-void read_regions_from_file(const std::string &filename, Regions &regions);
+void read_regions_from_file(std::string const &filename, Regions &regions);
 void read_regions_from_dcw(const char *codeNames, Regions &regions);
 
 #endif  //  REGION_H
