@@ -8,13 +8,13 @@
 #include <atomic>
 
 #include "cpp_lib.h"
-#include "process_int.h"
+#include "cdo_options.h"
+#include "cdo_output.h"
 #include "cdo_timer.h"
+#include "cdo_omp.h"
 #include "remap.h"
 #include "remap_store_link.h"
-#include "cdo_options.h"
 #include "progress.h"
-#include "cdo_omp.h"
 #include "grid_healpix.h"
 
 // bilinear interpolation
@@ -22,18 +22,18 @@
 static inline void
 limit_dphi_bounds(double &dphi)
 {
-  if (dphi > 3.0 * PIH) dphi -= PI2;
-  if (dphi < -3.0 * PIH) dphi += PI2;
+  if (dphi > 3.0 * PIH) { dphi -= PI2; }
+  else if (dphi < -3.0 * PIH) { dphi += PI2; }
 }
 
 std::pair<double, double>
-remap_find_weights(const PointLonLat &pointLL, const SquareCorners &squareCorners)
+remap_find_weights(PointLonLat const &pointLL, const SquareCorners &squareCorners)
 {
   constexpr double converge = 1.0e-10;  // Convergence criterion
-  extern long RemapMaxIteration;
+  constexpr long MaxIteration = 100;    // Max iteration count for i, j iteration
 
-  const auto &lons = squareCorners.lons;
-  const auto &lats = squareCorners.lats;
+  auto const &lons = squareCorners.lons;
+  auto const &lats = squareCorners.lats;
 
   // Iterate to find xfrac,yfrac for bilinear approximation
 
@@ -58,32 +58,32 @@ remap_find_weights(const PointLonLat &pointLL, const SquareCorners &squareCorner
   double yguess = 0.5;
 
   long iter = 0;  // iteration counters
-  for (iter = 0; iter < RemapMaxIteration; ++iter)
-    {
-      auto dthp = pointLL.get_lat() - lats[0] - dth1 * xguess - dth2 * yguess - dth3 * xguess * yguess;
-      auto dphp = pointLL.get_lon() - lons[0];
+  for (iter = 0; iter < MaxIteration; ++iter)
+  {
+    auto dthp = pointLL.lat() - lats[0] - dth1 * xguess - dth2 * yguess - dth3 * xguess * yguess;
+    auto dphp = pointLL.lon() - lons[0];
 
-      limit_dphi_bounds(dphp);
+    limit_dphi_bounds(dphp);
 
-      dphp -= dph1 * xguess + dph2 * yguess + dph3 * xguess * yguess;
+    dphp -= dph1 * xguess + dph2 * yguess + dph3 * xguess * yguess;
 
-      auto mat1 = dth1 + dth3 * yguess;
-      auto mat2 = dth2 + dth3 * xguess;
-      auto mat3 = dph1 + dph3 * yguess;
-      auto mat4 = dph2 + dph3 * xguess;
+    auto mat1 = dth1 + dth3 * yguess;
+    auto mat2 = dth2 + dth3 * xguess;
+    auto mat3 = dph1 + dph3 * yguess;
+    auto mat4 = dph2 + dph3 * xguess;
 
-      auto determinant = mat1 * mat4 - mat2 * mat3;
+    auto determinant = mat1 * mat4 - mat2 * mat3;
 
-      auto deli = (dthp * mat4 - dphp * mat2) / determinant;
-      auto delj = (dphp * mat1 - dthp * mat3) / determinant;
+    auto deli = (dthp * mat4 - dphp * mat2) / determinant;
+    auto delj = (dphp * mat1 - dthp * mat3) / determinant;
 
-      if (std::fabs(deli) < converge && std::fabs(delj) < converge) break;
+    if (std::fabs(deli) < converge && std::fabs(delj) < converge) break;
 
-      xguess += deli;
-      yguess += delj;
-    }
+    xguess += deli;
+    yguess += delj;
+  }
 
-  if (iter >= RemapMaxIteration) xguess = yguess = -1.0;
+  if (iter >= MaxIteration) xguess = yguess = -1.0;
 
   return std::make_pair(xguess, yguess);
 }
@@ -100,18 +100,18 @@ bilinear_set_weights(double xfrac, double yfrac, double (&weights)[4])
 }
 
 int
-num_src_points(const Vmask &mask, const size_t (&indices)[4], double (&lats)[4])
+num_src_points(Vmask const &mask, size_t const (&indices)[4], double (&lats)[4])
 {
   int num = 4;
 
   for (int i = 0; i < 4; ++i)
+  {
+    if (mask[indices[i]] == 0)
     {
-      if (mask[indices[i]] == 0)
-        {
-          num--;
-          lats[i] = 0.0;
-        }
+      num--;
+      lats[i] = 0.0;
     }
+  }
 
   return num;
 }
@@ -130,11 +130,13 @@ static void
 bilinear_sort_weights_by_index_zip(size_t (&indices)[4], double (&weights)[4])
 {
   auto r = std::views::zip(indices, weights);
-  std::sort(r.begin(), r.end(), [](auto a, auto b) {
-    auto [ai, aw] = a;  // std::tuple
-    auto [bi, bw] = b;
-    return (ai < bi);
-  });
+  std::sort(r.begin(), r.end(),
+            [](auto a, auto b)
+            {
+              auto [ai, aw] = a;
+              auto [bi, bw] = b;
+              return (ai < bi);
+            });
 }
 #endif
 
@@ -152,18 +154,18 @@ bilinear_sort_weights_by_index(size_t (&indices)[4], double (&weights)[4])
   std::array<IndexWeightX, numWeights> indexWeights;
 
   for (size_t i = 0; i < numWeights; ++i)
-    {
-      indexWeights[i].index = indices[i];
-      indexWeights[i].weight = weights[i];
-    }
+  {
+    indexWeights[i].index = indices[i];
+    indexWeights[i].weight = weights[i];
+  }
 
-  ranges::sort(indexWeights, {}, &IndexWeightX::index);
+  std::ranges::sort(indexWeights, {}, &IndexWeightX::index);
 
   for (size_t i = 0; i < numWeights; ++i)
-    {
-      indices[i] = indexWeights[i].index;
-      weights[i] = indexWeights[i].weight;
-    }
+  {
+    indices[i] = indexWeights[i].index;
+    weights[i] = indexWeights[i].weight;
+  }
 }
 
 static void
@@ -184,14 +186,14 @@ bilinear_warning()
 {
   static auto printWarning = true;
   if (Options::cdoVerbose || printWarning)
-    {
-      printWarning = false;
-      cdo_warning("Bilinear interpolation failed for some grid points - used a distance-weighted average instead!");
-    }
+  {
+    printWarning = false;
+    cdo_warning("Bilinear interpolation failed for some grid points - used a distance-weighted average instead!");
+  }
 }
 
 static void
-remap_bilinear_weights_regular(RemapSearch &rsearch, const Vmask &srcGridMask, const PointLonLat &pointLL, double &tgtCellFrac,
+remap_bilinear_weights_regular(RemapSearch &rsearch, Vmask const &srcGridMask, PointLonLat const &pointLL, double &tgtCellFrac,
                                size_t tgtCellIndex, std::vector<WeightLinks> &weightLinks)
 {
   SquareCorners squareCorners;
@@ -205,53 +207,53 @@ remap_bilinear_weights_regular(RemapSearch &rsearch, const Vmask &srcGridMask, c
 
   // If point found, find local xfrac/yfrac coordinates for weights
   if (searchResult > 0)
-    {
-      tgtCellFrac = 1.0;
+  {
+    tgtCellFrac = 1.0;
 
-      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
-      if (xfrac >= 0.0 && yfrac >= 0.0)
-        {
-          // Successfully found xfrac, yfrac - compute weights
-          bilinear_set_weights(xfrac, yfrac, weights);
-          store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
-        }
-      else
-        {
-          bilinear_warning();
-          searchResult = -1;
-        }
+    auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
+    if (xfrac >= 0.0 && yfrac >= 0.0)
+    {
+      // Successfully found xfrac, yfrac - compute weights
+      bilinear_set_weights(xfrac, yfrac, weights);
+      store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
     }
+    else
+    {
+      bilinear_warning();
+      searchResult = -1;
+    }
+  }
 
   // Search for bilinear failed - use a distance-weighted average instead
   // (this is typically near the pole) Distance was stored in srcLats!
   if (searchResult < 0)
+  {
+    if (num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
     {
-      if (num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
-        {
-          tgtCellFrac = 1.0;
-          renormalize_weights(squareCorners.lats, weights);
-          store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
-        }
+      tgtCellFrac = 1.0;
+      renormalize_weights(squareCorners.lats, weights);
+      store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
     }
+  }
 }
 
 static void
-remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Vmask &srcGridMask, const PointLonLat &pointLL,
+remap_bilinear_weights_healpix(RemapSearch const &rsearch, Vmask const &srcGridMask, PointLonLat const &pointLL,
                                double &tgtCellFrac, size_t tgtCellIndex, std::vector<WeightLinks> &weightLinks)
 {
   double weights[4];  // bilinear weights for four corners
   size_t indices[4];  // indices for the four source points
 
-  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.get_lon(), pointLL.get_lat(), indices, weights);
+  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.lon(), pointLL.lat(), indices, weights);
 
   // Check to see if points are mask points
   auto searchResult = remap_check_mask_indices(indices, srcGridMask);
   if (searchResult > 0)
-    {
-      tgtCellFrac = 1.0;
-      bilinear_sort_weights(indices, weights);
-      store_weightlinks(0, 4, indices, weights, tgtCellIndex, weightLinks);
-    }
+  {
+    tgtCellFrac = 1.0;
+    bilinear_sort_weights(indices, weights);
+    store_weightlinks(0, 4, indices, weights, tgtCellIndex, weightLinks);
+  }
 }
 
 // -----------------------------------------------------------------------
@@ -288,23 +290,23 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
-    {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && tgtGridSize > progressMinSize) { progress.update((double) atomicCount / tgtGridSize); }
 
-      weightLinks[tgtCellIndex].nlinks = 0;
+    weightLinks[tgtCellIndex].nlinks = 0;
 
-      if (!tgtGrid->mask[tgtCellIndex]) continue;
+    if (!tgtGrid->mask[tgtCellIndex]) continue;
 
-      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+    auto pointLL = tgtGrid->get_lonlat(tgtCellIndex);
 
-      auto &tgtCellFrac = tgtGrid->cellFrac[tgtCellIndex];
-      if (isHealpixGrid)
-        remap_bilinear_weights_healpix(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
-      else
-        remap_bilinear_weights_regular(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
-    }
+    auto &tgtCellFrac = tgtGrid->cellFrac[tgtCellIndex];
+    if (isHealpixGrid)
+      remap_bilinear_weights_healpix(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
+    else
+      remap_bilinear_weights_regular(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
+  }
 
   weight_links_to_remap_links(0, tgtGridSize, weightLinks, rv);
 
@@ -315,14 +317,14 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
 
 template <typename T>
 static inline T
-bilinear_remap(const Varray<T> &srcArray, const double (&wgt)[4], const size_t (&ind)[4])
+bilinear_remap(Varray<T> const &srcArray, size_t const (&ind)[4], double const (&wgt)[4])
 {
   return srcArray[ind[0]] * wgt[0] + srcArray[ind[1]] * wgt[1] + srcArray[ind[2]] * wgt[2] + srcArray[ind[3]] * wgt[3];
 }
 
 template <typename T1, typename T2>
 static void
-remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const Vmask &srcGridMask, const PointLonLat &pointLL,
+remap_bilinear_regular(RemapSearch &rsearch, Varray<T1> const &srcArray, Vmask const &srcGridMask, PointLonLat const &pointLL,
                        T2 &tgtValue)
 {
   SquareCorners squareCorners;
@@ -336,52 +338,52 @@ remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const V
 
   // If point found, find local xfrac/yfrac coordinates for weights
   if (searchResult > 0)
+  {
+    auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
+    if (xfrac >= 0.0 && yfrac >= 0.0)
     {
-      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
-      if (xfrac >= 0.0 && yfrac >= 0.0)
-        {
-          // Successfully found xfrac, yfrac - compute weights
-          bilinear_set_weights(xfrac, yfrac, weights);
-          bilinear_sort_weights(squareCorners.indices, weights);
-          tgtValue = bilinear_remap(srcArray, weights, squareCorners.indices);
-        }
-      else
-        {
-          bilinear_warning();
-          searchResult = -1;
-        }
+      // Successfully found xfrac, yfrac - compute weights
+      bilinear_set_weights(xfrac, yfrac, weights);
+      bilinear_sort_weights(squareCorners.indices, weights);
+      tgtValue = bilinear_remap(srcArray, squareCorners.indices, weights);
     }
+    else
+    {
+      bilinear_warning();
+      searchResult = -1;
+    }
+  }
 
   // Search for bilinear failed - use a distance-weighted average instead
   // (this is typically near the pole) Distance was stored in srcLats!
   if (searchResult < 0)
+  {
+    if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
     {
-      if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
-        {
-          renormalize_weights(squareCorners.lats, weights);
-          bilinear_sort_weights(squareCorners.indices, weights);
-          tgtValue = bilinear_remap(srcArray, weights, squareCorners.indices);
-        }
+      renormalize_weights(squareCorners.lats, weights);
+      bilinear_sort_weights(squareCorners.indices, weights);
+      tgtValue = bilinear_remap(srcArray, squareCorners.indices, weights);
     }
+  }
 }
 
 template <typename T1, typename T2>
 static void
-remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, const Vmask &srcGridMask, const PointLonLat &pointLL,
+remap_bilinear_healpix(const RemapSearch &rsearch, Varray<T1> const &srcArray, Vmask const &srcGridMask, PointLonLat const &pointLL,
                        T2 &tgtValue)
 {
-  double weights[4];  // bilinear weights for four corners
   size_t indices[4];  // indices for the four source points
+  double weights[4];  // bilinear weights for four corners
 
-  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.get_lon(), pointLL.get_lat(), indices, weights);
+  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.lon(), pointLL.lat(), indices, weights);
 
   // Check to see if points are mask points
   auto searchResult = remap_check_mask_indices(indices, srcGridMask);
   if (searchResult > 0)
-    {
-      bilinear_sort_weights(indices, weights);
-      tgtValue = bilinear_remap(srcArray, weights, indices);
-    }
+  {
+    bilinear_sort_weights(indices, weights);
+    tgtValue = bilinear_remap(srcArray, indices, weights);
+  }
 }
 
 // -----------------------------------------------------------------------
@@ -389,7 +391,7 @@ remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, c
 // -----------------------------------------------------------------------
 template <typename T1, typename T2>
 static void
-remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
+remap_bilinear(Varray<T1> const &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
 {
   T1 missval = srcMissval;
   const auto srcGrid = rsearch.srcGrid;
@@ -420,32 +422,30 @@ remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissv
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
-    {
-      atomicCount++;
-      auto ompthID = cdo_omp_get_thread_num();
-      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
+  {
+    atomicCount++;
+    auto ompthID = cdo_omp_get_thread_num();
+    if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
 
-      auto &tgtValue = tgtArray[tgtCellIndex];
-      tgtValue = missval;
+    auto &tgtValue = tgtArray[tgtCellIndex];
+    tgtValue = missval;
 
-      if (!tgtGrid->mask[tgtCellIndex]) continue;
+    if (!tgtGrid->mask[tgtCellIndex]) continue;
 
-      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+    auto pointLL = tgtGrid->get_lonlat(tgtCellIndex);
 
-      if (isHealpixGrid)
-        remap_bilinear_healpix(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
-      else
-        remap_bilinear_regular(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
-    }
+    if (isHealpixGrid)
+      remap_bilinear_healpix(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
+    else
+      remap_bilinear_regular(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
+  }
 
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bilinear
 
 void
-remap_bilinear(RemapSearch &remapSearch, const Field &field1, Field &field2)
+remap_bilinear(RemapSearch &remapSearch, Field const &field1, Field &field2)
 {
-  auto func = [&](const auto &v1, auto &v2, double missval, size_t numMissVals) {
-    remap_bilinear(v1, v2, missval, numMissVals, remapSearch);
-  };
-  field_operation2(func, field1, field2, field1.missval, field1.numMissVals);
+  auto func = [&](auto const &v1, auto &v2) { remap_bilinear(v1, v2, field1.missval, field1.numMissVals, remapSearch); };
+  field_operation2(func, field1, field2);
 }
