@@ -24,49 +24,49 @@ struct CellSearch
   realloc(size_t numCells, bool allocBarycenters = false)
   {
     if (numCells > maxCells)
+    {
+      partialAreas.resize(numCells);
+      overlapCells.resize(numCells);
+      gridCells.resize(numCells);
+
+      for (size_t i = maxCells; i < numCells; ++i)
       {
-        partialAreas.resize(numCells);
-        overlapCells.resize(numCells);
-        gridCells.resize(numCells);
+        overlapCells[i].array_size = 0;
+        overlapCells[i].num_corners = 0;
+        overlapCells[i].edge_type = nullptr;
+        overlapCells[i].coordinates_xyz = nullptr;
 
-        for (size_t i = maxCells; i < numCells; ++i)
-          {
-            overlapCells[i].array_size = 0;
-            overlapCells[i].num_corners = 0;
-            overlapCells[i].edge_type = nullptr;
-            overlapCells[i].coordinates_xyz = nullptr;
-
-            gridCells[i].array_size = numCorners;
-            gridCells[i].num_corners = numCorners;
-            gridCells[i].edge_type = edgeType;
-            gridCells[i].coordinates_xyz = new double[numCorners][3];
-          }
-
-        if (allocBarycenters) overlapBarycenters = new double[numCells][3];
-
-        maxCells = numCells;
+        gridCells[i].array_size = numCorners;
+        gridCells[i].num_corners = numCorners;
+        gridCells[i].edge_type = edgeType;
+        gridCells[i].coordinates_xyz = new double[numCorners][3];
       }
+
+      if (allocBarycenters) overlapBarycenters = new double[numCells][3];
+
+      maxCells = numCells;
+    }
   }
 
   void
   free()
   {
     for (size_t i = 0; i < maxCells; ++i)
+    {
+      if (overlapCells[i].array_size > 0)
       {
-        if (overlapCells[i].array_size > 0)
-          {
-            if (overlapCells[i].coordinates_xyz) std::free(overlapCells[i].coordinates_xyz);
-            if (overlapCells[i].edge_type) std::free(overlapCells[i].edge_type);
-          }
-
-        delete[] gridCells[i].coordinates_xyz;
+        if (overlapCells[i].coordinates_xyz) { std::free(overlapCells[i].coordinates_xyz); }
+        if (overlapCells[i].edge_type) { std::free(overlapCells[i].edge_type); }
       }
 
+      delete[] gridCells[i].coordinates_xyz;
+    }
+
     varray_free(partialAreas);
     varray_free(overlapCells);
     varray_free(gridCells);
 
-    if (overlapBarycenters) delete[] overlapBarycenters;
+    if (overlapBarycenters) { delete[] overlapBarycenters; }
   }
 };
 
