@@ -14,28 +14,28 @@ struct RemapVars;
 
 struct IndexWeight
 {
-  size_t index;
-  double weight;
+  size_t index{};
+  double weight{};
 };
 
 struct IndexWeight4
 {
-  size_t index;
-  double weight[4];
+  size_t index{};
+  double weight[4]{};
 };
 
 struct WeightLinks
 {
-  size_t nlinks;
-  size_t offset;
-  IndexWeight *indexWeights;
+  size_t nlinks{};
+  size_t offset{};
+  IndexWeight *indexWeights{};
 };
 
 struct WeightLinks4
 {
-  size_t nlinks;
-  size_t offset;
-  IndexWeight4 *indexWeights;
+  size_t nlinks{};
+  size_t offset{};
+  IndexWeight4 *indexWeights{};
 };
 
 bool is_sorted_list(size_t n, const size_t *list);
