@@ -73,12 +73,12 @@ struct RemapVars
   Varray<double> weights;         // map weights for each link [maxLinks*numWeights]
 };
 
-void remap_field(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1,
+void remap_field(Field &field2, double missval, size_t gridsize2, RemapVars const &rv, Field const &field1,
                  RemapGradients &gradients);
-void remap_laf(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1);
-void remap_avg(Field &field2, double missval, size_t gridsize2, const RemapVars &rv, const Field &field1);
+void remap_laf(Field &field2, double missval, size_t gridsize2, RemapVars const &rv, Field const &field1);
+void remap_avg(Field &field2, double missval, size_t gridsize2, RemapVars const &rv, Field const &field1);
 void remap_vars_init(RemapMethod mapType, int remapOrder, RemapVars &rv);
 void remap_vars_free(RemapVars &rv);
-void remap_vars_check_weights(const RemapVars &rv);
+void remap_vars_check_weights(RemapVars const &rv);
 
 #endif /* REMAP_VARS_H */
