@@ -34,81 +34,81 @@ results_template_parser(void *node, const char *varname)
   if (a_node == nullptr) return 1;
 
   if (cdo_cmpstr((const char *) a_node->name, "results"))
+  {
+    const char *value = (const char *) xmlGetProp(a_node, (const xmlChar *) "version");
+
+    if (value)
     {
-      const char *value = (const char *) xmlGetProp(a_node, (const xmlChar *) "version");
+      if (DBG_MSG) printf("Version %s \n", value);
 
-      if (value)
-        {
-          if (DBG_MSG) printf("Version %s \n", value);
-
-          if (atof(value) > 3.0f) return 1;
-        }
+      if (atof(value) > 3.0f) return 1;
     }
+  }
 
   for (cur_node = a_node->children; cur_node; cur_node = cur_node->next)
-    {
+  {
 #if 0
       xmlChar *param_name = nullptr;
       char *param_type = nullptr;
 #endif
-      param_value = nullptr;
+    param_value = nullptr;
 
-      if (cur_node->type == XML_ELEMENT_NODE)
-        {
+    if (cur_node->type == XML_ELEMENT_NODE)
+    {
 
-          if (DBG_MSG) printf("Node Name: %s \n", cur_node->name);
+      if (DBG_MSG) printf("Node Name: %s \n", cur_node->name);
 
-          if (cur_node->properties == nullptr)
-            {
-              if (cur_node->children == nullptr) printf("NO ATTRIBUTES!!!\n");
-            }
-          else
-            {
-              // Loop Over the attributes and get the corresponding  Magics Parameter name and type, set the value
+      if (cur_node->properties == nullptr)
+      {
+        if (cur_node->children == nullptr) printf("NO ATTRIBUTES!!!\n");
+      }
+      else
+      {
+        // Loop Over the attributes and get the corresponding  Magics Parameter name and type, set the value
 #if 0
 	      printf( "Finding varname = %s  result_name = %s\n", varname, xmlGetProp( cur_node,"name") );
 #endif
 
-              if (std::strcmp(varname, (const char *) xmlGetProp(cur_node, (xmlChar *) "name")) == 0)
-                {
+        if (std::strcmp(varname, (const char *) xmlGetProp(cur_node, (xmlChar *) "name")) == 0)
+        {
 #if 0
 	          printf( "Found varname = %s  result_name = %s\n", varname, xmlGetProp( cur_node,"name") );
 #endif
-                  for (attr = cur_node->properties; attr; attr = attr->next)
-                    {
-                      if (attr != nullptr)
-                        {
-                          param_value = xmlNodeGetContent(attr->children);
+          for (attr = cur_node->properties; attr; attr = attr->next)
+          {
+            if (attr != nullptr)
+            {
+              param_value = xmlNodeGetContent(attr->children);
 
-                          // if( !get_magics_parameter_info( attr->name, &magics_param_name, &param_type ) )
-                          if (!get_magics_parameter_info((const char *) attr->name, (char *) param_value))
-                            {
+              // if( !get_magics_parameter_info( attr->name, &magics_param_name, &param_type ) )
+              if (!get_magics_parameter_info((const char *) attr->name, (char *) param_value))
+              {
 #if 0
 			      printf("Done corresponding Magics Parameter found!\n");
 			      printf("Setting corresponding Magics Parameter %s and type %s!\n",magics_param_name, param_type );
-	  		      fprintf(stderr, "param_value: %s\n", param_value);
+	  		      std::fprintf(stderr, "param_value: %s\n", param_value);
 			      _set_magics_parameter_value( magics_param_name, param_type, param_value );
 #endif
-                            }
-                          else
-                            {
+              }
+              else
+              {
 #if 0
 			      printf("No corresponding Magics Parameter found!\n");
 #endif
-                            }
-                        }
-                    }
-
-                  break;
-                }
-              else
-                {
-                  fprintf(stderr, "Var Name not matching resetting Magics Params!\n");
-                  // Call the Reset functions of all the features to Reset the magics params to default
-                }
+              }
             }
+          }
+
+          break;
         }
+        else
+        {
+          std::fprintf(stderr, "Var Name not matching resetting Magics Params!\n");
+          // Call the Reset functions of all the features to Reset the magics params to default
+        }
+      }
     }
+  }
 
   return 0;
 }
