@@ -71,16 +71,16 @@ public:
 #define SELINFO_GET_VAL(name, valIdx, val) selinfo_get_val(selInfo, listIdx_##name, valIdx, val)
 #define SELINFO_DEF_VAL(name, valIdx, val) selinfo_def_val(selInfo, listIdx_##name, valIdx, val)
 
-int selinfo_add(SelectInfo &selInfo, const std::string &description, const std::string &name, SelType type);
-void selinfo_check_flag(const SelectInfo &selInfo, int listIdx);
-void selinfo_check_range_flag(const SelectInfo &selInfo, int listIdx);
+int selinfo_add(SelectInfo &selInfo, std::string const &description, std::string const &name, SelType type);
+void selinfo_check_flag(SelectInfo const &selInfo, int listIdx);
+void selinfo_check_range_flag(SelectInfo const &selInfo, int listIdx);
 bool selinfo_check(SelectInfo &selInfo, int listIdx, void *par);
 bool selinfo_check_index(SelectInfo &selInfo, int listIdx, int par, int maxValues);
 bool selinfo_check_date(SelectInfo &selInfo, int listIdx, const char *par);
 bool selinfo_check_season(SelectInfo &selInfo, int listIdx, int month);
 bool selinfo_check_range(SelectInfo &selInfo, int listIdx, double value);
 void selinfo_def_flag(SelectInfo &selInfo, int listIdx, int valIdx, bool flag);
-void selinfo_get_val(const SelectInfo &selInfo, int listIdx, int valIdx, void *val);
+void selinfo_get_val(SelectInfo const &selInfo, int listIdx, int valIdx, void *val);
 void selinfo_def_val(SelectInfo &selInfo, int listIdx, int valIdx, void *val);
 
 #endif
