@@ -6,7 +6,7 @@
 namespace cdo
 {
 
-int define_table(const std::string &tablearg);
+int define_table(std::string const &tablearg);
 std::string predefined_tables(int p_padding);
 
 }  // namespace cdo
