@@ -18,7 +18,7 @@ enum
 #define SET_DATE(dtstr, date, time) (snprintf(dtstr, sizeof(dtstr), "%*ld%*d", CMP_DATE - 6, (long) date, 6, time))
 
 inline bool
-date_is_neq(const CdiDateTime &dateTime1, const CdiDateTime &dateTime2, int compareDate)
+date_is_neq(CdiDateTime const &dateTime1, CdiDateTime const &dateTime2, int compareDate)
 {
   char dateStr1[CMP_DATE + 1], dateStr2[CMP_DATE + 1];
   SET_DATE(dateStr1, cdiDate_get(dateTime1.date), cdiTime_get(dateTime1.time));
