@@ -10,13 +10,11 @@
 #include <vector>
 #include <string>
 
-char *expand_filename(const char *args);
+char *expand_filename(const char *fileName);
 
 std::vector<std::string> expand_path_names(std::vector<std::string> argv);
-
 std::vector<std::string> expand_wild_cards(std::vector<std::string> argv);
 
-int wildcardmatch(const char *w, const char *s);
-int wildcardmatch(const std::string &w, const std::string &s);
+bool wildcard_match(std::string const &text, std::string const &pattern);
 
 #endif
