@@ -25,11 +25,6 @@ private:
   };
 
   std::function<void()> function;
-  bool useFunction{ false };
-
-  void *(*routine)(void *) = nullptr;
-  void *arg = nullptr;
-  void *result = nullptr;
 
   State state{ State::SETUP };
   std::thread thread;
@@ -42,9 +37,9 @@ private:
 public:
   WorkerThread();
   ~WorkerThread();
+
   void doAsync(const std::function<void()> &_function);
-  void start(void *(*task_routine)(void *), void *task_arg);
-  void *wait();
+  void wait();
 };
 
 #endif /* WORKERTHREAD_H */
